"""
Game: Wordle Solver
-------------------

Version: 5.17.0
Date updated: 20/11/2025 (dd/mm/yyyy)

Usage:
------
>>> Wordle().solve()

Credit:
-------
- [Code](https://www.inspiredpython.com/article/solving-wordle-puzzles-with-basic-python)
- [Words](https://raw.githubusercontent.com/dwyl/english-words/master/words_dictionary.json)
"""

# Module level
# ---------------------------------------------------------------------------
__all__ = ["Wordle"]


# Library
# ---------------------------------------------------------------------------
import operator
import string
from collections import Counter
from itertools import chain

import requests

# Class
# ---------------------------------------------------------------------------
OFFLINE_WORDS = """\
aahed,aalii,aargh,aaron,abaca,abaci,aback,abada,abaff,abaft,abaka,abama,abamp,aband,abase,abash,abask,abate,abaue,abave,abaze,abbas,abbes,abbey,abbie,abbot,abdal,abdat,abdom,abeam,abear,abede,abele,abend,aberr,abets,abhor,abide,abidi,abies,abilo,abime,abkar,abler,ables,ablet,ablow,abmho,abner,abnet,abode,abody,abohm,aboil,aboma,aboon,abord,abort,abote,about,above,abram,abray,abret,abrim,abrin,abris,abrus,absee,absey,absis,absit,abstr,abuna,abune,abura,abuse,abush,abuta,abuts,abuzz,abwab,abyes,abysm,abyss,acale,acana,acapu,acara,acari,acast,acate,accel,accoy,accra,accts,accum,accur,accus,acedy,acerb,aceta,achar,ached,achen,acher,aches,achoo,achor,acids,acidy,acier,acies,acing,acini,ackee,acker,ackey,aclys,acmes,acmic,acned,acnes,acock,acoin,acold,acoma,acone,acool,acorn,acost,acoup,acrab,acred,acres,acrid,acroa,acron,acrux,acryl,acted,actin,acton,actor,actos,actus,acuan,acute,acyls,adage,adagy,adams,adapa,adapt,adati,adaty,adawe,adawn,adays,adcon,addax,addda,added,adder,addie,addio,addis,addle,addnl,adead,adeem,adeep,adela,adeps,adept,adfix,adiel,adieu,adion,adios,adits,adjag,adlai,adlay,adlet,adman,admen,admin,admit,admix,admov,admrx,adnex,adobe,adobo,adolf,adopt,adore,adorn,adown,adoxa,adoxy,adoze,adpao,adrad,adret,adrip,adrop,adrue,adsum,adult,adunc,adure,adusk,adust,adyta,adzer,adzes,aecia,aedes,aeger,aegir,aegis,aegle,aeons,aequi,aeric,aerie,aeron,aesir,aesop,aetat,aevia,aevum,aface,afara,afars,afear,affix,afgod,afifi,afire,aflat,afley,aflow,afoam,afoot,afore,afoul,afray,afret,afric,afrit,afros,after,agada,agade,again,agama,agami,agamy,agape,agars,agasp,agast,agata,agate,agaty,agave,agaze,agena,agend,agene,agent,agers,agete,agger,aggie,aggro,aggry,aggur,aghan,aghas,agiel,agile,aging,agios,agism,agist,aglee,aglet,agley,aglow,agmas,agnat,agnel,agnes,agnus,agoge,agoho,agone,agons,agony,agora,agrah,agral,agree,agria,agric,agrin,agrom,agron,agsam,agues,aguey,agura,agush,agust,ahead,aheap,ahems,ahind,ahint,ahmed,ahmet,ahold,aholt,ahong,ahsan,ahull,ahunt,ahura,ahush,ahwal,aided,aider,aides,aiery,aiger,aigre,ailed,ailie,aillt,aimak,aimed,aimee,aimer,ainee,ainoi,ainus,aioli,airan,aired,airer,airns,airth,airts,aisle,aitch,aitis,aiver,aiwan,aizle,ajaja,ajari,ajava,ajhar,ajiva,ajuga,akala,akali,akasa,akebi,akees,akeki,akela,akene,aking,akkad,aknee,aknow,akpek,akron,akule,akund,alack,alada,alain,alaki,alala,alamo,aland,alane,alang,alani,alans,alant,alapa,alarm,alary,alate,alawi,alban,albas,albee,albin,album,albus,albyn,alcae,alces,alcid,alcor,alday,aldea,alden,alder,aldim,aldol,aldus,aleak,
aleck,alecs,alefs,aleft,alenu,aleph,alert,aleut,alfas,alfet,alfin,alfur,algae,algal,algas,algic,algid,algin,algol,algor,algum,alhet,alias,alibi,alice,alick,alida,alids,alien,aliet,alife,alifs,align,alike,alima,aline,alish,aliso,alisp,alist,alite,ality,alive,aliya,alkes,alkin,alkyd,alkyl,allah,allan,allay,allen,aller,alley,allez,allie,allis,allod,alloo,allot,allow,alloy,allyl,almah,alman,almas,almeh,almes,almon,almud,almug,alnus,alody,aloed,aloes,aloft,alogy,aloha,aloid,aloin,alois,aloma,alone,along,aloof,alosa,alose,aloud,alout,alowe,alpax,alpen,alpha,alpid,altar,alter,altho,altin,altos,altun,altus,aluco,alula,alums,alure,aluta,alvah,alvan,alvar,alvia,alvin,alvus,alway,amaas,amadi,amaga,amahs,amain,amala,amalg,amang,amani,amant,amapa,amara,amass,amate,amati,amaut,amaze,amban,ambar,ambas,ambay,amber,ambit,amble,ambon,ambos,ambry,ameba,ameed,ameen,ameer,amelu,amend,amene,amens,ament,amess,amhar,amias,amice,amici,amide,amido,amids,amies,amiga,amigo,amine,amini,amino,amins,amire,amirs,amish,amiss,amita,amity,amlet,amman,ammer,ammos,amnia,amnic,amoke,amoks,amole,among,amora,amort,amour,amove,amowt,amper,amphi,ample,amply,ampul,ampyx,amrit,amsel,amuck,amula,amuse,amuze,amvis,amylo,amyls,amzel,anabo,anack,anama,anana,anasa,ancha,ancle,ancon,ancor,ancre,andes,andia,andor,andre,anear,anele,anend,anent,angas,angel,anger,angia,angie,angka,angle,anglo,angor,angry,angst,angus,anhyd,aniba,anice,anigh,anile,anils,anima,anime,animi,animo,anion,anise,anita,anjan,anjou,ankee,anker,ankhs,ankle,ankou,ankus,anlas,anlet,anlia,anmia,annal,annam,annas,annat,annet,annex,annie,anniv,annot,annoy,annul,annum,annus,anoas,anode,anoia,anoil,anole,anoli,anomy,anorn,anour,anous,anova,ansae,ansar,ansel,anser,antae,antal,antar,antas,anted,antes,antic,antiq,antis,anton,antra,antre,antsy,antum,anura,anury,anvil,anzac,aoife,aorta,aotea,aotes,aotus,aouad,apace,apaid,apair,apama,apart,apass,apast,apeak,apeek,apers,apert,aperu,apery,aphid,aphis,aphra,apian,apiin,apili,apina,aping,apiol,apios,apish,apism,apium,apnea,apoda,apods,apoop,aport,apout,appal,appar,appay,appel,appet,apple,apply,appmt,appro,apptd,appui,apres,april,apron,apses,apsid,apsis,aptal,apter,aptly,aquae,aquas,araba,arabs,araby,araca,arace,arach,arado,arage,arain,arake,araks,aramu,arank,arara,araru,arase,arati,araua,arawa,arber,arbor,arcae,arced,arces,archd,arche,archt,archy,arcos,arcus,ardea,ardeb,arder,ardor,ardri,aread,areae,areal,arean,arear,areas,areca,areek,areel,arefy,areic,arena,arend,areng,arent,arere,arest,arete,argal,argan,argas,argel,argid,argil,
argin,argle,argol,argon,argos,argot,argue,argus,arhar,arhat,arian,arias,ariel,aries,ariki,arils,arioi,arion,ariot,arise,arish,arist,arite,arith,arius,arjun,arkab,arkie,arles,armed,armer,armet,armil,armit,armor,arneb,arnee,arnut,aroar,arock,aroid,aroma,aroon,aroph,arose,arpen,arrah,arras,arrau,array,arret,arrgt,arrha,arrie,arris,arrow,arroz,arses,arsis,arsle,arson,arsyl,artal,artar,artel,arter,artha,artic,artie,artly,artou,artsy,artus,aruac,aruke,arulo,arums,arupa,arusa,arval,arvel,arvos,aryan,aryls,arzan,arzun,asale,asana,asaph,asarh,ascan,ascii,ascon,ascot,ascry,ascus,asdic,asgmt,ashed,ashen,asher,ashes,ashet,ashir,ashot,ashur,asian,aside,askar,asked,asker,askew,askip,askoi,askos,aslop,asoak,asoka,aspca,aspen,asper,aspic,aspis,assai,assam,assay,asses,asset,assis,assoc,assot,astay,astel,aster,astir,astor,astre,astur,asuri,asway,aswim,asyla,asyle,async,atake,atame,atavi,ataxy,ateba,atees,atelo,ately,athar,athel,atilt,atimy,ating,atlas,atlee,atman,atmas,atmid,atmos,atnah,atoke,atole,atoll,atoms,atomy,atone,atony,atopy,atour,atren,atria,atrip,attal,attar,atter,attic,attid,attle,attry,atule,atune,atwin,atypy,aubin,aucan,aucht,audad,audio,audit,aueto,augen,auger,auget,aught,augur,aulae,aulas,aulic,auloi,aulos,aumil,aunts,aunty,aurae,aural,aurar,auras,aurei,aures,auric,aurin,aurir,auris,aurum,auryl,autem,autor,autos,autre,auxil,auxin,avahi,avail,avale,avant,avars,avast,avell,avena,avens,aveny,avera,avern,avers,avert,avery,avgas,avian,avick,aview,avile,avine,avion,aviso,avoid,avoir,avoke,avoue,avour,avowe,avows,awabi,awacs,awaft,await,awake,awald,awalt,awane,award,aware,awarn,awash,awave,aways,awber,aweek,aweel,awest,aweto,awful,awhet,awhir,awide,awing,awink,awiwi,awkly,awned,awner,awoke,awols,awork,axels,axers,axial,axile,axils,axine,axing,axiom,axion,axite,axled,axles,axman,axmen,axoid,axone,axons,ayahs,ayelp,ayens,ayins,aylet,ayllu,ayond,ayont,ayous,ayuyu,azans,azide,azido,azine,azlon,azoch,azofy,azoic,azole,azons,azote,azoth,azoxy,aztec,azure,azury,azyme,
baaed,baals,babai,babas,babby,babel,babes,babis,babka,bable,baboo,babua,babul,babus,bacao,bacca,baccy,bache,bacin,bacis,backs,backy,bacon,badan,baddy,badge,badju,badly,badon,baffs,baffy,bafta,bagdi,bagel,bagge,baggy,bagie,bagio,bagle,bagne,bagre,bahai,baham,bahan,bahar,bahay,bahoe,bahoo,bahts,bahur,bahut,baign,baile,bailo,bails,baioc,bairn,baith,baits,baiza,baize,bajan,bajau,bajra,bajri,bakal,baked,baken,baker,bakes,bakie,bakli,bakra,balai,balak,balan,balao,balas,balat,balau,balds,baldy,baled,balei,baler,bales,balks,balky,balli,ballo,balls,bally,balms,balmy,balon,baloo,balor,balow,balsa,balti,balun,balut,balza,bamah,banak,banal,banat,banba,banca,banco,banda,bande,bandh,bandi,bando,bands,bandy,baned,banes,banff,banga,bange,bangs,bangy,bania,banig,banjo,banks,banky,banns,bantu,banty,banus,banya,barad,barat,barba,barbe,barbs,barbu,barde,bardo,bards,bardy,bared,barer,bares,baret,barff,barfs,barfy,barge,bargh,baria,baric,barid,barie,barih,baris,barit,barks,barky,barly,barms,barmy,barns,barny,baroi,baron,barra,barre,barry,barse,barth,barye,basad,basal,basan,basat,based,baser,bases,basic,basil,basin,basis,baske,basks,bason,basos,bassa,bassi,basso,bassy,basta,baste,basti,basto,basts,basyl,batad,batak,batan,batch,batea,bated,batel,bater,bates,bathe,baths,batik,batis,baton,batta,batts,battu,batty,batwa,baubo,bauch,bauds,bauge,bauld,baulk,baume,bauno,baure,bauta,bavin,bawds,bawdy,bawke,bawls,bawly,bawra,bawty,bayal,bayed,bayok,bayou,bazar,bazoo,beach,beads,beady,beaks,beaky,beala,beams,beamy,beano,beans,beant,beany,beard,bearm,bears,beast,beata,beath,beati,beats,beaus,beaut,beaux,bebar,bebat,bebay,bebed,bebog,bebop,becap,becco,beche,becks,becky,becry,becut,bedad,beday,bedel,beden,bedew,bedim,bedin,bedip,bedog,bedot,bedub,bedur,bedye,beech,beedi,beefs,beefy,beele,beent,beeps,beers,beery,beest,beeth,beets,beety,beeve,befan,befit,befog,befop,befur,begad,began,begar,begat,begay,begem,beget,begin,begob,begod,begot,begum,begun,begut,behap,behav,behen,behew,beice,beige,beigy,beild,being,beira,beisa,bejan,bejel,bejig,bekah,bekko,belah,belam,belap,belar,belat,belay,belch,belee,belga,belie,belis,bella,belle,belli,bello,bells,belly,below,belts,belue,belve,bemad,beman,bemar,bemas,bemat,bemba,bemix,bemol,bemud,benab,bench,benda,bends,bendy,benes,benet,benic,benim,benin,benjy,benne,benni,benny,bensh,bents,benty,benzo,beode,bepat,bepaw,bepen,bepun,berat,beray,beret,bergh,bergs,bergy,berme,berms,berne,berob,beroe,berri,berry,berth,berun,beryl,beryx,besan,besee,beset,besew,besin,besit,besom,besot,bespy,besra,
bessi,bessy,bests,betag,betas,betel,betes,beths,betis,beton,betso,betsy,betta,betty,bevel,bever,bevil,bevor,bevue,bevvy,bewet,bewig,bewit,bewry,bezan,bezel,bezil,bezzi,bezzo,bhaga,bhalu,bhang,bhara,bhava,bhili,bhima,bhoot,bhuts,biabo,biali,bialy,bibbs,bibby,bibio,bible,bicep,bices,bichy,bidar,biddy,bided,bider,bides,bidet,bidri,bidry,bield,biens,biers,bifer,biffs,biffy,bifid,bigae,bigam,bigas,biggy,bigha,bight,bigly,bigot,bihai,biham,bijou,biked,biker,bikes,bikie,bikol,bilbi,bilbo,bilby,bilch,biles,bilge,bilgy,bilic,bilin,bilio,bilks,billa,bills,billy,bilos,bilsh,bimah,bimas,bimbo,binal,bindi,binds,bines,binge,bingo,bingy,binit,binna,binny,bints,biome,biont,biose,biota,biped,bipod,birch,birde,birds,birdy,birks,birky,birle,birls,birma,birne,birny,biron,birri,birrs,birse,birsy,birth,bises,biset,bisie,bisks,bisme,bison,bisso,bisti,bitch,bited,biter,bites,bitis,bitsy,bitte,bitts,bitty,biune,bivvy,bixin,bizel,bizen,bizes,bizet,blabs,black,blade,blady,blaff,blahs,blain,blair,blake,blame,blams,blanc,bland,blank,blare,blart,blase,blash,blast,blate,blats,blawn,blaws,blayk,blaze,blazy,bleak,blear,bleat,blebs,bleck,bleed,bleep,blend,blenk,blens,blent,blere,bless,blest,blets,blibe,blick,blier,blimp,blimy,blind,blini,blink,bliny,blips,blirt,bliss,blist,blite,blitz,blizz,bloat,blobs,block,blocs,bloke,blond,blood,bloom,bloop,blore,blote,blots,blout,blown,blows,blowy,blued,bluer,blues,bluet,bluey,bluff,blume,blunk,blunt,blurb,blurs,blurt,blush,blype,board,boars,boart,boast,boats,bobac,bobby,bobet,bobol,bocal,bocca,bocce,bocci,boche,bocks,bocoy,boded,boden,boder,bodes,bodge,bodhi,bodle,boers,boffo,boffs,bogan,boget,bogey,boggy,bogie,bogle,bogue,bogum,bogus,bohea,bohor,boiko,boils,boily,boing,boise,boist,boite,bokom,bokos,bolag,bolar,bolas,boldo,boldu,boled,boles,bolis,bolls,bolly,bolos,bolti,bolts,bolty,bolus,bombe,bombo,bombs,bomos,bonav,bonbo,bonce,bonds,boned,boner,bones,boney,bongo,bongs,bonks,bonne,bonny,bonos,bonum,bonus,bonze,boobs,booby,boodh,boody,booed,books,booky,booly,booms,boomy,boone,boong,boonk,boons,boors,boort,boose,boost,boosy,booth,boots,booty,booze,boozy,borak,boral,boran,boras,borax,bored,boree,borel,borer,bores,borgh,boric,borid,boris,borne,boron,borts,borty,bortz,boryl,bosch,boser,bosey,bosks,bosky,bosom,boson,bossa,bossy,bosun,botan,botas,botch,botel,bothy,botry,botte,botts,bottu,bouch,boucl,bouet,bouge,bough,boule,boult,bound,bourd,bourg,bourn,bourr,bouse,bousy,bouto,bouts,bovey,bovid,bovld,bowed,bowel,bower,bowet,bowge,bowie,bowla,bowle,bowls,bowly,bowne,bowse,boxed,boxen,
boxer,boxes,boxty,boyar,boyau,boyce,boyer,boyla,boyos,bozal,bozos,bozze,braca,brace,brach,brack,bract,brads,braes,bragi,brags,brahm,braid,brail,brain,brake,braky,brame,brand,brank,brans,brant,brash,brass,brast,brats,brava,brave,bravi,bravo,brawl,brawn,braws,braxy,braye,brays,braza,braze,bread,break,bream,breba,breck,brede,bredi,breed,breek,brees,breme,brens,brent,brerd,brere,brest,breth,brett,breva,breve,brevi,brews,brian,briar,bribe,brick,bride,brief,brier,bries,brigs,brike,brill,brims,brine,bring,brink,brins,briny,brios,brisa,brise,brisk,briss,brist,brite,brith,brits,britt,briza,brizz,broad,broch,brock,brogh,broid,broil,broke,broll,broma,brome,bromo,bronc,bronk,bronx,brood,brook,brool,broom,broon,broos,brose,brosy,broth,brott,browd,brown,brows,brubu,bruce,bruet,brugh,bruin,bruit,bruja,brujo,bruke,brule,brume,brune,bruno,brunt,brush,brusk,bruta,brute,bruzz,bryan,bryce,bryon,bryum,btise,buaze,bubal,bubas,bubba,bubby,bubos,bucca,bucco,buchu,bucko,bucks,bucku,bucky,buddh,buddy,budge,budgy,bueno,buffa,buffe,buffi,buffo,buffs,buffy,bugan,buggy,bught,bugle,bugre,buhls,buhrs,buick,build,built,buist,bukat,bulak,bulbs,bulby,bulge,bulgy,bulks,bulky,bulla,bulls,bully,bulse,bumbo,bumfs,bumph,bumps,bumpy,bunce,bunch,bunco,bunda,bundh,bunds,bundt,bundu,bundy,bunga,bungo,bungs,bungy,bunko,bunks,bunns,bunny,bunts,bunty,bunya,buoys,buran,burao,buras,burbs,burds,burel,buret,burez,burga,burge,burgh,burgs,burin,burka,burke,burls,burly,burma,burns,burnt,burny,buroo,burps,burro,burrs,burry,bursa,burse,burst,burut,burys,busby,bused,buses,bushi,bushy,busks,busky,bussu,bussy,busti,busto,busts,busty,butat,butch,butea,buteo,butic,butin,butle,butsu,butte,butts,butty,butut,butyl,butyn,butyr,buxom,buxus,buyer,buzzy,bwana,byard,bylaw,bynin,byous,byres,byrls,byron,byrri,bysen,byssi,bytes,byway,
caaba,caama,cabaa,cabal,caban,cabas,cabby,cabda,caber,cabin,cabio,cable,cabob,cabot,cabre,cacam,cacan,cacao,cacas,cacei,cache,cacks,cacti,cacur,caddo,caddy,cadee,cader,cades,cadet,cadew,cadge,cadgy,cadie,cadis,cados,cadre,cadua,cadus,caeca,cafes,caffa,cafiz,cafoy,caged,cager,cages,cagey,caggy,cagit,cagot,cagui,cahiz,cahot,cahow,cahuy,caids,cains,caird,cairn,cairo,caite,cajan,cajon,cajou,cajun,caked,caker,cakes,cakey,cakra,calas,calci,caleb,calef,calfs,calic,calid,calif,calin,calix,calks,calla,calli,callo,calls,calms,calmy,calor,calve,calyx,caman,camas,camay,camel,cameo,cames,camis,camla,campa,campe,campi,campo,camps,campy,camus,canal,canap,canch,candy,caned,canel,caner,canes,cangy,canid,canis,canli,canna,canny,canoe,canon,canos,canso,canst,canto,cants,canty,canun,canzo,caoba,capax,caped,capel,caper,capes,caphs,capoc,capon,capos,capot,cappy,capra,capri,capsa,caput,caque,carap,carat,carbo,carby,cardo,cards,cared,carer,cares,caret,carex,carey,carga,cargo,carib,carid,carks,carle,carli,carlo,carls,carne,carns,carny,caroa,carob,carol,carom,carot,carpe,carpi,carps,carri,carrs,carry,carse,carte,carts,carty,carua,carum,carus,carve,carvy,carya,caryl,casal,casas,casco,cased,casel,caser,cases,casey,casha,casks,casky,casse,cassy,caste,casts,casus,catan,catch,catel,cater,cates,catha,cathy,catso,catti,catty,catur,cauch,cauda,cauld,cauli,caulk,cauls,cauma,caupo,causa,cause,cavae,caval,cavea,caved,cavel,caver,caves,cavey,cavia,cavie,cavil,cavin,cavum,cavus,cawed,cawky,cawny,caxon,cayos,ccitt,ccoya,cease,cebid,cebil,cebur,cebus,cecal,cecca,cecil,cecum,cedar,ceded,ceder,cedes,cedis,cedre,cedry,ceiba,ceibo,ceile,ceils,ceint,celeb,celia,cella,celli,cello,cells,celom,celts,cense,centi,cento,cents,ceorl,cepes,cequi,ceral,ceras,cerat,cerci,cered,cerer,ceres,ceria,ceric,cerin,ceros,certy,ceryl,cesar,cesta,ceste,cesti,cetes,cetic,cetid,cetin,cetus,cetyl,chace,chack,chaco,chads,chafe,chaff,chaft,chaga,chain,chair,chais,chait,chaja,chaka,chalk,chama,chamm,champ,chams,chane,chang,chank,chant,chaos,chape,chaps,chapt,chara,chard,chare,chark,charm,charr,chars,chart,chary,chase,chasm,chass,chati,chats,chaui,chauk,chaum,chaus,chave,chawk,chawl,chawn,chaws,chaya,chays,chazy,cheap,cheat,check,cheek,cheep,cheer,cheet,chefs,chego,cheir,cheka,cheke,cheki,chela,chelp,chena,cheng,chera,chere,chert,chese,chess,chest,cheth,cheve,chevy,chews,chewy,chiam,chian,chiao,chias,chiba,chica,chich,chick,chico,chics,chide,chief,chiel,chien,child,chile,chili,chill,chimb,chime,chimp,chimu,china,chine,ching,chink,chino,chins,chint,chiot,
chips,chirk,chirl,chirm,chiro,chirp,chirr,chirt,chiru,chita,chits,chive,chivw,chivy,chizz,chloe,chlor,choak,choca,chock,choco,choel,choes,choga,choil,choir,choke,choko,choky,chola,chold,choli,cholo,chomp,chonk,chook,choom,choop,chopa,chops,chora,chord,chore,chort,chose,chott,choup,chous,chout,choux,chowk,chows,choya,chria,chris,chron,chubb,chubs,chuck,chude,chuet,chufa,chuff,chugs,chuje,chump,chums,chung,chunk,churl,churm,churn,churr,chuse,chute,chwas,chyak,chyle,chyme,cibol,cicad,cicer,cider,cigar,cigua,cilia,cimex,cinch,cinct,cindy,cinel,cines,cions,cippi,circa,circe,circs,cires,cirri,cisco,cissy,cista,cists,cital,cited,citee,citer,cites,citua,civet,civic,civie,civil,civvy,cizar,clach,clack,clade,clads,claes,clags,claik,claim,clair,clake,clamb,clame,clamp,clams,clang,clank,clans,clape,claps,clapt,clara,clare,clark,claro,clart,clary,clash,clasp,class,clast,claus,claut,clava,clave,clavi,clavy,clawk,claws,claye,clays,clead,cleam,clean,clear,cleat,cleck,cleek,clefs,cleft,clepe,clept,clerk,cleuk,cleve,clews,clich,click,cliff,clift,clima,climb,clime,cline,cling,clink,clint,clips,clipt,clite,clive,cloak,cloam,clock,clods,cloes,cloff,clogs,cloit,cloke,cloky,clomb,clomp,clone,clong,clonk,clons,cloof,cloop,cloot,clops,close,closh,clote,cloth,clots,cloud,clour,clout,clove,clown,cloys,cloze,clubs,cluck,clued,clues,cluff,clump,clung,clunk,clyde,clyer,clype,cnida,coach,coact,coaid,coala,coals,coaly,coapt,coarb,coart,coast,coati,coats,coaxy,cobbs,cobby,cobia,coble,cobol,cobra,cobus,cocao,cocas,cocci,cocco,cocin,cocks,cocky,cocle,cocoa,cocos,cocus,codal,codas,coddy,codec,coded,coden,coder,codes,codex,codol,codon,coeds,coeff,coeno,coffs,cogie,cogit,cogon,cogue,cohen,cohob,cohog,cohol,cohos,cohow,cohue,coifs,coign,coils,coing,coins,coiny,coirs,coked,coker,cokes,cokey,cokie,colan,colas,colat,colds,colen,coles,colet,coley,colic,colin,colla,colly,colob,colog,colon,color,colts,colza,comae,comal,coman,comas,combe,combo,combs,comby,comdg,comdr,comdt,comer,comes,comet,comfy,comic,comid,comma,comme,commo,commy,comox,compd,compo,comps,compt,comte,comus,conal,conch,concn,condo,coned,coner,cones,coney,confr,conga,conge,congo,conia,conic,conin,conks,conky,conli,conns,connu,conny,conor,conoy,const,consy,contd,conte,contg,conto,contr,conus,cooba,cooch,cooed,cooee,cooer,cooey,coofs,cooja,cooks,cooky,cools,cooly,coomb,coomy,coons,coony,coops,coopt,coorg,coost,cooth,coots,cooty,copal,coped,copei,copen,coper,copes,copia,copis,coppa,copps,coppy,copra,copse,copsy,copus,coque,corah,coral,coram,coran,corbe,corby,cords,
cordy,cored,coree,corer,cores,corey,corge,corgi,coria,corin,corke,corks,corky,corms,corno,corns,cornu,corny,coroa,corol,corpl,corpn,corps,corse,corso,corsy,corta,corve,corvo,coryl,cosec,cosed,cosen,coses,coset,cosey,cosie,cosin,cosmo,cosse,costa,costs,cotan,cotch,coted,cotes,cothe,cothy,cotta,cotte,cotty,cotys,couac,couch,coude,cough,could,couma,count,coupe,coups,courb,cours,court,couth,couve,coved,coven,cover,coves,covet,covey,covid,covin,cowal,cowan,cowed,cower,cowle,cowls,cowry,coxae,coxal,coxed,coxes,coyan,coyed,coyer,coyly,coyol,coyos,coypu,cozed,cozen,cozes,cozey,cozie,craal,crabs,crack,craft,crags,craie,craig,craik,crain,crake,cramp,crams,crane,crang,crank,crany,crape,craps,crapy,crare,crash,crass,crate,crave,cravo,crawl,crawm,craws,craye,craze,crazy,crcao,crche,cread,creak,cream,creat,creda,credo,creed,creek,creel,creem,creen,creep,crees,creme,crena,crepe,crept,crepy,cresc,cress,crest,creta,crete,crewe,crews,cribo,cribs,crick,cried,crier,cries,criey,crile,crime,crimp,crine,crink,crips,crisp,criss,crith,croak,croat,croci,crock,croft,crois,crome,crone,cronk,crony,crood,crook,crool,croon,crops,crore,crosa,crose,cross,crost,croup,crout,crowd,crowl,crown,crows,croyl,croze,cruce,cruck,crude,cruds,crudy,cruel,cruet,crull,crumb,crump,crunk,crunt,cruor,crura,cruse,crush,crust,cruth,crwth,cryal,crypt,cryst,csect,csnet,ctene,ctimo,cuban,cubas,cubby,cubeb,cubed,cuber,cubes,cubic,cubit,cubla,cubti,cucuy,cuddy,cueca,cueva,cuffs,cuffy,cufic,cuifs,cuing,cuish,cujam,cukes,culch,culet,culex,culla,culls,cully,culms,culmy,culot,culpa,culti,cults,cumal,cumar,cumay,cumbu,cumic,cumin,cumly,cumol,cumyl,cunan,cunas,cundy,cunea,cunei,cunit,cunni,cunny,cunts,cunye,cunza,cupay,cupel,cupid,cuppa,cuppy,curat,curbs,curby,curch,curds,curdy,cured,curer,cures,curet,curfs,curia,curie,curin,curio,curls,curly,curns,currs,curry,cursa,curse,curst,curua,curve,curvy,cusec,cushy,cusie,cusks,cusps,cusso,cutch,cuter,cutes,cutey,cutie,cutin,cutis,cutty,cutup,cuvee,cuyas,cyano,cyans,cyath,cycad,cycas,cycle,cyclo,cyder,cydon,cylix,cymae,cymar,cymas,cymba,cymes,cymol,cymry,cynic,cypre,cyril,cyrus,cysts,cytol,cyton,czars,czech,
dabba,dabby,dabih,dabuh,daces,dacha,dachs,dacus,dadap,dadas,daddy,dados,daeva,daffs,daffy,dafla,dagga,daggy,dagon,dagos,dahms,daijo,daily,daint,daira,dairi,dairt,dairy,daisy,daiva,daker,dakir,dalai,dalan,dalar,dalea,daler,dales,dalis,dalle,dally,daman,damar,damas,dames,damia,damie,damme,damns,damon,damps,dampy,danae,danai,dance,dancy,danda,dandy,danes,dangs,danic,danio,danke,danli,danny,dansk,dansy,danta,dante,darac,daraf,darat,darbs,darby,darci,darcy,dared,daren,darer,dares,dargo,daric,darii,darin,darks,darky,darns,daroo,darst,darts,darya,daryl,dasht,dashy,dasnt,dassy,dasya,datch,dated,dater,dates,datil,datos,datsw,datto,datum,daube,daubs,dauby,dauke,dault,daunt,dauri,dauts,daven,daver,david,davis,davit,dawdy,dawed,dawen,dawks,dawns,dawny,dawts,dawut,dayak,dayal,dayan,dazed,dazes,deads,deady,deair,deals,dealt,deans,deare,dearn,dears,deary,deash,death,deave,debag,debar,debat,debby,debel,deben,debit,debts,debug,debus,debut,debye,decad,decal,decan,decap,decay,decem,decil,decke,decks,decor,decoy,decry,decus,decyl,dedal,dedan,deddy,dedit,deeds,deedy,deems,deeny,deeps,deers,deess,defat,defer,defet,defis,defix,defog,degas,degum,deice,deify,deign,deils,deink,deino,deism,deist,deity,deked,dekes,dekko,dekle,delaw,delay,deled,deles,delfs,delft,delhi,delia,delim,delis,delit,della,dells,delly,deloo,delph,delta,delve,demal,demes,demit,demob,demon,demos,demot,demur,denar,denat,denay,denda,deneb,denes,denim,denis,denom,dense,dents,denty,deota,depas,depel,depit,depoh,depot,depth,derah,derat,deray,derby,derek,deric,deriv,derma,derms,derog,derri,derry,derth,derve,desex,desks,desma,dessa,desto,desyl,detar,detat,detax,deter,detin,dette,detur,deuce,deval,devas,devel,devex,devil,devon,devot,devow,dewal,dewan,dewar,dewax,dewed,dewer,dewey,dexes,deynt,dhabb,dhaks,dhava,dheri,dhikr,dhobi,dhoby,dhole,dhoni,dhoon,dhoti,dhoty,dhoul,dhows,dhuti,dhyal,diact,diaka,dials,diamb,diana,diane,diary,diazo,diced,dicer,dices,dicey,dicht,dicks,dicky,dicot,dicta,dicty,didal,diddy,didie,didle,didna,didnt,didos,didst,didus,didym,diego,diene,dieri,diets,diety,difda,dight,digit,digne,digor,digue,diked,diker,dikes,dildo,dilis,dilli,dills,dilly,dilos,dimer,dimes,dimin,dimit,dimly,dimmy,dimna,dimps,dinah,dinar,dined,diner,dines,dinge,dingo,dings,dingy,dinic,dinka,dinks,dinky,dinos,dints,dinus,diode,diols,dione,dioon,diose,diota,dioti,dioxy,diple,dippy,dipso,dipsy,dipus,dirca,direr,direx,dirge,dirgy,dirks,dirls,dirts,dirty,disci,disco,discs,dishy,disks,disli,disme,disna,distn,distr,disty,dital,ditas,ditch,diter,dites,ditto,ditty,
diurn,divan,divas,dived,divel,diver,dives,divet,divia,divid,divot,divus,divvy,diwan,dixie,dixit,dizen,dizzy,djave,djinn,djins,djuka,doand,doats,doaty,dobby,dobie,dobla,dobos,dobra,docks,doddy,dodge,dodgy,dodos,doers,doesn,doest,doeth,doffs,dogal,doges,dogey,doggo,doggy,dogie,dogly,dogma,dogra,doigt,doily,doina,doing,doits,dojos,dolce,dolci,doled,doles,doley,dolia,dolls,dolly,dolor,dolos,dolph,dolts,dolus,domal,domba,domed,domer,domes,domic,dompt,domus,donal,donar,donas,donat,donax,doncy,donec,donee,donet,doney,donga,dongs,donia,donis,donna,donne,donny,donor,donsy,donum,donut,dooja,dooli,dooly,dooms,doors,doozy,dopas,doped,doper,dopes,dopey,dorab,dorad,doray,doree,dorey,doria,doric,doris,dorje,dorms,dormy,dorps,dorrs,dorsa,dorse,dorsi,dorts,dorty,dosed,doser,doses,dosis,dossy,dotal,doted,doter,dotes,dotty,douar,doubt,douce,dough,dougl,douma,doura,douse,doven,dover,doves,dovey,dowdy,dowed,dowel,dower,dowie,dowly,downs,downy,dowry,dowse,dowve,doxie,doyen,doyle,doylt,doyly,doyst,dozed,dozen,dozer,dozes,draba,drabs,draco,draff,draft,drago,drags,drail,drain,drake,drama,drame,dramm,drams,drang,drank,drant,drape,drate,drats,drave,drawk,drawl,drawn,draws,drays,dread,dream,drear,dreck,dreed,dreep,drees,dregs,dreks,dreng,drent,dress,drest,drias,dribs,dried,drier,dries,drift,drill,drily,drink,drinn,drips,dript,drisk,drive,drogh,droil,droit,droll,drome,drona,drone,drony,droob,drool,droop,drops,dropt,dross,droud,drouk,drove,drovy,drown,droyl,drubs,drugs,druid,drums,drung,drunk,drunt,drupa,drupe,drury,druse,drusy,druxy,druze,dryad,dryas,dryer,dryly,dryth,dsect,dtset,duads,duala,duali,duals,duane,duant,dubba,dubby,dubhe,dubio,ducal,ducat,duces,duchy,ducks,ducky,ducts,duddy,dudes,duels,duets,duffs,duffy,dugal,duhat,duits,dujan,dukes,dukhn,dulat,dulce,duler,dulia,dulls,dully,dulse,dumas,dumba,dumbs,dumby,dumka,dumky,dummy,dumps,dumpy,dunal,dunce,dunch,dunes,dungs,dungy,dunks,dunne,dunno,dunny,dunst,dunts,duole,duomi,duomo,duped,duper,dupes,dupla,duple,duply,duppa,duppy,dural,duras,durax,dured,duree,dures,duret,durio,durns,duroc,duros,duroy,durra,durrs,durry,durst,durum,duryl,durzi,dusio,dusks,dusky,dusts,dusty,dusun,dutch,dutra,duvet,duxes,dvigu,dwale,dwalm,dwang,dwarf,dwell,dwelt,dwine,dwyka,dyads,dyaus,dyers,dying,dyked,dyker,dykes,dylan,dynam,dynel,dynes,
eably,eager,eagle,eagre,eared,earle,earls,early,earns,earsh,earth,eased,easel,easer,eases,easts,eaten,eater,eaved,eaver,eaves,ebbed,ebbet,eblis,ebons,ebony,ecart,echar,echea,eched,eches,echis,echos,ecize,eclat,ecoid,ecole,ecrus,ectad,ectal,edana,edder,eddic,eddie,edema,edgar,edged,edger,edges,edict,edify,edile,edith,edits,ediya,edoni,educe,educt,edwin,eeler,eemis,eerie,eeten,effet,effie,egads,egall,egers,egest,eggar,egged,egger,egret,egrid,egypt,eider,eidos,eight,eigne,eikon,eimak,eimer,eject,ejido,ejusd,ekaha,eking,ekron,elaic,elain,elamp,eland,elans,elaps,elate,elayl,elbow,elder,eldin,elean,elect,elegy,eleme,elemi,eleut,eleve,elfic,elfin,elian,elias,elide,elihu,eliot,elite,eliza,ellan,ellen,elmer,eloah,eloge,elogy,eloin,elong,elope,elops,elric,elses,elsin,elude,elute,elvan,elver,elves,elvet,elvis,elymi,email,emane,embar,embay,embed,ember,embog,embow,embox,embue,embus,emcee,emden,emeer,emend,emery,emesa,emeus,emigr,emily,emirs,emits,emlen,emmer,emmet,emmew,emong,emony,emory,emote,emove,empeo,empty,emule,emuls,emyde,emyds,enact,enage,enami,enapt,enarm,enate,encia,encup,encyc,ended,ender,endew,endia,endow,endue,eneas,eneid,enema,enemy,enent,enfin,engem,engin,engle,enhat,eniac,enjoy,enlay,enmew,ennew,ennia,ennoy,ennui,enoch,enode,enoil,enols,enorm,enorn,enows,enpia,enray,enrib,enrol,enrut,ensky,ensue,entad,ental,entea,enter,entia,entom,entre,entry,entte,enure,envoi,envoy,enweb,enzym,eoith,eosin,epact,epees,epeus,ephah,ephas,ephod,ephoi,ephor,epics,epiky,epist,eplot,epoch,epode,epopt,epoxy,eppes,eppie,epris,epsom,epulo,equal,eques,equid,equip,equiv,equus,erade,erase,erato,erava,erbia,erect,erept,ergal,ergon,ergot,erian,erica,erick,erika,erizo,ermit,ernes,ernie,ernst,erode,erose,erred,erron,error,ersar,erses,eruca,eruct,erugo,erump,erupt,ervil,ervum,erwin,eryon,esbay,escar,escot,escry,esere,eshin,eskar,esker,espec,esrog,essay,essed,essee,esses,essex,essie,estab,ester,estoc,estop,estre,estus,etang,etape,ethal,ethan,ethel,ether,ethic,ethid,ethos,ethyl,etiam,etnas,etrog,ettle,etude,etuis,etuve,etwas,etwee,etyma,eucre,eucti,euler,eupad,euros,eurus,eusol,evade,evang,evans,evase,eveck,evene,evens,event,evert,every,evese,evict,evils,evite,evoke,ewder,ewers,ewery,ewest,ewhow,ewing,exact,exalt,exams,exaun,excel,excud,excur,exdie,exeat,execs,exect,exede,exert,exhbn,exies,exile,exine,exing,exion,exist,exite,exits,exlex,exode,exody,exopt,expdt,expel,expos,exptl,expwy,exsec,exter,extol,extra,exude,exult,exurb,exust,exxon,eyass,eyers,eyess,eyght,eying,eyoty,eyrar,eyras,eyren,eyrer,eyres,eyrie,eyrir,
faade,fabes,fable,faced,facer,faces,facet,facia,facie,facit,facks,facto,facts,facty,faddy,faded,faden,fader,fades,fadge,fadme,fados,faena,faery,faffy,fager,faggy,fagin,fagot,fagus,faham,fails,fains,faint,faire,fairm,fairs,fairy,faith,faits,faked,faker,fakes,fakir,falco,falda,falla,falls,fally,false,falun,falus,famed,fames,fanal,fanam,fancy,fanes,fanga,fango,fangs,fangy,fanit,fanny,fanon,fanos,fanti,fanum,fanwe,faqir,farad,farce,farci,farcy,farde,fardh,fardo,fards,fared,farer,fares,fario,farle,farls,farms,farmy,faros,farse,farsi,farth,farts,fasti,fasts,fatal,fated,fates,fatil,fatly,fator,fatso,fatty,fatwa,faugh,fauld,fault,faulx,fauna,fauns,faurd,fause,faust,faute,fauve,favel,favor,favus,fawns,fawny,faxed,faxes,fayal,fayed,fazed,fazes,fchar,fcomp,fconv,fdubs,fears,fease,feast,feats,featy,feaze,fecal,feces,fecit,fecks,fedia,feeds,feedy,feels,feely,feere,feest,feeze,feign,feint,feist,felid,felis,felix,fella,fells,felly,felon,felts,felty,felup,femes,femic,femme,femur,fence,fends,fendy,fenks,fenny,feods,feoff,ferae,feral,feres,feria,ferie,ferio,ferly,ferme,fermi,ferns,ferny,ferox,ferri,ferry,ferth,fesse,festa,feste,festy,fetal,fetas,fetch,feted,fetes,fetid,fetis,fetor,fetus,fetwa,feuar,feuds,feued,feute,fever,fewer,feyer,fezes,fezzy,fgrid,fhrer,fiant,fiard,fiars,fiats,fiber,fibra,fibre,fibro,fibry,fices,fiche,fichu,ficin,ficus,fidac,fidel,fides,fidge,fidia,fidos,fiefs,field,fiend,fient,fieri,fiery,fifed,fifer,fifes,fifie,fifth,fifty,figgy,fight,fiked,fikey,fikie,filao,filar,filch,filea,filed,filer,files,filet,filii,filix,filla,fille,fills,filly,films,filmy,filth,filum,final,finca,finch,finds,findy,fined,finer,fines,finew,fingu,finis,finks,finns,finny,fiord,fique,firca,fired,firer,fires,firma,firms,firns,firry,first,firth,fiscs,fishy,fists,fisty,fitch,fitly,fitty,fiver,fives,fixed,fixer,fixes,fixup,fizzy,fjeld,fjord,flabs,flack,flaff,flags,flail,flain,flair,flake,flaky,flamb,flame,flams,flamy,flane,flang,flank,flans,flaps,flare,flary,flash,flask,flats,flavo,flawn,flaws,flawy,flaxy,flays,flche,fldxt,fleak,fleam,flear,fleas,fleay,fleck,flect,fleer,flees,fleet,flegm,fleme,flesh,fleta,fleur,flews,flexo,fleys,flick,flics,flied,flier,flies,flimp,fling,flint,flipe,flips,flirt,flisk,flite,flits,fload,float,flock,flocs,floes,floey,flogs,floit,flong,flood,flook,floor,flops,flora,flory,flosh,floss,flota,flote,flots,flour,flout,flowe,flowk,flown,flows,floyd,floyt,flrie,flubs,flued,fluer,flues,fluey,fluff,fluid,fluke,fluky,flume,flump,flung,flunk,fluor,flurn,flurr,flurt,flush,flusk,flute,fluty,fluyt,
flyby,flyer,flype,flyte,fname,fnese,foals,foaly,foams,foamy,focal,focus,fodda,foder,fodge,foehn,foeti,fogas,fogey,foggy,fogie,fogle,fogon,fogou,fogus,fohat,fohns,foils,foins,foism,foist,folds,foldy,folia,folic,folie,folio,folks,folky,folly,fomes,fonds,fondu,fonly,fonts,foods,foody,fools,foots,footy,foppy,foram,foray,forbs,forby,force,forcy,fordo,fords,fordy,forel,fores,foret,forex,forge,forgo,forks,forky,forma,forme,forms,formy,forra,forst,forte,forth,forts,forty,forum,fosie,fossa,fosse,fotch,fotui,fouls,found,fount,fourb,fours,foute,fouth,fouty,fovea,fowls,foxed,foxer,foxes,foxie,foxly,foyer,fplot,fpsps,frack,fract,frags,fraid,fraik,frail,frame,franc,frank,franz,frape,frapp,fraps,frary,frase,frass,frate,frats,fraud,fraus,frawn,frayn,frays,fraze,frden,freak,fream,freck,freed,freen,freer,frees,freet,freir,freit,fremd,fremt,frena,freon,frere,fresh,fress,frets,frett,freud,freya,freyr,friar,fried,frier,fries,frigs,frija,frike,frill,frise,frisk,friss,frist,frith,frits,fritt,fritz,frize,frizz,frock,froes,frogs,frond,frons,front,froom,frore,frory,frosh,frosk,frost,froth,frowl,frown,frows,frowy,froze,frugs,fruit,frump,frush,frust,fryer,fuage,fubby,fubsy,fuchi,fucks,fucus,fuder,fudge,fudgy,fuels,fuffy,fugal,fuggy,fugie,fugio,fugit,fugle,fugue,fujis,fulah,fulls,fully,fulth,fultz,fulup,fulwa,fumed,fumer,fumes,fumet,fumid,fundi,funds,funge,fungi,fungo,funic,funis,funje,funks,funky,funli,funny,fural,furan,furca,furil,furls,furor,furry,furud,furyl,furze,furzy,fused,fusee,fusel,fuses,fusht,fusil,fussy,fusty,fusus,futwa,fuzed,fuzee,fuzes,fuzil,fuzzy,fyces,fykes,fytte,
gabby,gable,gabon,gaddi,gader,gades,gadge,gadid,gadis,gadso,gadus,gaels,gaffe,gaffs,gaged,gagee,gager,gages,gagor,gaily,gaine,gains,gaist,gaits,gaitt,gaius,gaize,galah,galas,galax,galbe,galea,galee,galei,galen,gales,galet,galey,galga,galik,galla,galli,galls,gally,galop,galut,galvo,gamba,gambe,gambs,gamed,gamer,games,gamey,gamic,gamin,gamma,gammy,gamps,gamut,ganam,ganch,ganda,ganef,ganev,ganga,gange,gangs,ganja,ganof,gansa,gansy,ganta,ganza,gaols,gaped,gaper,gapes,gappy,garad,garau,garbo,garbs,garce,garde,gardy,gareh,garle,garni,garon,garoo,garse,garth,garua,garum,gasan,gases,gashy,gasps,gaspy,gassy,gasts,gatch,gated,gater,gates,gatha,gator,gauby,gaucy,gauds,gaudy,gauge,gauls,gault,gaums,gaumy,gaunt,gaura,gaure,gaurs,gauss,gauze,gauzy,gavel,gavia,gavot,gawby,gawks,gawky,gawsy,gayal,gayer,gayly,gazed,gazee,gazel,gazer,gazes,gazet,gazon,gazoz,gconv,gears,gease,geast,gebur,gecko,gecks,gedds,geeks,geese,geest,gehey,geira,geisa,geist,gekko,gelds,gelee,gelid,gelly,gelts,gemel,gemma,gemmy,gemot,gemse,gemul,genae,genal,genep,genes,genet,genic,genie,genii,genin,genio,genip,genit,genny,genoa,genom,genos,genre,genro,gents,genty,genua,genus,genys,geode,geoff,geoid,geoty,gerah,gerbe,gerbo,gerim,gerip,germs,germy,gesan,gesso,geste,gests,getae,getah,getas,getfd,getic,getid,getup,geums,geyan,ghain,ghana,ghast,ghats,ghaut,ghazi,ghbor,ghees,ghent,ghess,ghole,ghoom,ghost,ghoul,ghyll,giant,gibbi,gibby,gibed,gibel,giber,gibes,gibli,gibus,giddy,gifts,gigas,gigge,gighe,gigot,gigue,giher,gilds,giles,gilet,gilia,gilim,gills,gilly,gilpy,gilse,gilts,gilty,gimel,gimme,gimps,gimpy,ginep,ginks,ginny,ginzo,gipon,gippo,gippy,gipsy,girba,girds,girja,girls,girly,girns,girny,giron,giros,girse,girsh,girth,girts,gisel,gisla,gismo,gists,gitim,giust,given,giver,gives,givey,givin,gizmo,glace,glack,glade,glads,glady,glaga,glaik,glair,glaky,glali,gland,glans,glare,glary,glass,glaum,glaur,glaux,glave,glaze,glazy,glead,gleam,glean,gleba,glebe,gleby,glede,gleds,gledy,gleed,gleek,gleen,glees,gleet,gleir,gleit,glene,glenn,glens,glent,gleys,glial,glick,glide,gliff,glike,glime,glims,glink,glint,glisk,gliss,glist,gloam,gloat,globe,globs,globy,gloea,glogg,glome,glomi,gloms,glood,gloom,glops,glore,glory,gloss,glost,glout,glove,glows,gloze,gluck,glued,gluer,glues,gluey,gluma,glume,glump,gluon,gluts,glynn,glyph,gnarl,gnarr,gnars,gnash,gnast,gnats,gnawn,gnaws,gnide,gnoff,gnome,goads,goala,goals,goats,goaty,goave,goban,gobbe,gobby,gobet,gobia,gobio,gobos,godet,godly,goers,goety,gofer,gogga,gogos,going,goldi,golds,goldy,golee,golem,goles,
golet,golfs,golgi,golly,goloe,golpe,gombo,gomer,gonad,gonal,gondi,goner,goney,gongs,gonia,gonid,gonif,gonna,gonne,gonof,gonys,gonzo,goods,goody,gooey,goofs,goofy,gooks,gooky,gools,gooma,goons,goony,goops,goopy,goose,goosy,gopak,goral,goran,gorce,gored,gorer,gores,gorge,goric,gorki,gorra,gorry,gorse,gorst,gorsy,gossy,gotch,goter,gotha,goths,gotos,gotra,gotta,gouda,goudy,gouge,goumi,goura,gourd,goury,gouts,gouty,gowan,gowds,gowdy,gowks,gowns,goxes,goyim,goyin,goyle,graal,grabs,grace,gracy,grade,grads,graff,graft,grail,grain,graip,grama,grame,gramp,grams,gramy,grana,grand,grane,grank,grano,grant,grape,graph,grapy,grasp,grass,grata,grate,grave,gravy,grays,graze,great,grebe,grebo,grece,greco,greed,greek,green,grees,greet,grege,gregg,grego,grein,greit,grene,greta,grete,grewt,greys,grice,gride,grids,grief,griff,grift,grigs,grike,grill,grime,grimm,grimp,grimy,grind,grins,grint,griot,gripe,griph,grips,gript,gripy,grise,grist,grith,grits,groan,groat,groff,grogs,groin,groma,grond,gront,groof,groom,groop,groot,groow,grope,gross,grosz,grote,grots,grouf,group,grout,grove,grovy,growl,grown,grows,grubs,gruel,grues,gruff,gruft,gruis,grume,grump,grunt,grush,gruss,gruys,gryde,grype,gryph,gteau,guaba,guaco,guaka,guama,guana,guano,guans,guara,guard,guars,guary,guasa,guato,guava,guaza,gubat,gubbo,gucki,gucks,gudes,gudge,gudok,guelf,guess,guest,guffs,guffy,gugal,guiac,guiba,guide,guido,guids,guige,guijo,guild,guile,guilt,guily,guiro,guise,gujar,gulae,gular,gulas,gulch,gules,gulfs,gulfy,gulix,gulls,gully,gulph,gulps,gulpy,gumbo,gumby,gumly,gumma,gummy,gunda,gundi,gundy,gunge,gunja,gunks,gunky,gunne,gunny,guppy,guran,gurdy,gurge,guric,gurle,gurly,gurry,gursh,gurts,gurus,guser,gushy,gusla,gusle,gussy,gusto,gusts,gusty,gutsy,gutta,gutte,gutti,gutty,guyed,guyer,guyot,guzul,gweed,gwely,gwine,gybed,gybes,gyges,gygis,gymel,gynic,gyppo,gypsy,gyral,gyred,gyres,gyric,gyron,gyros,gyrus,gyved,gyves,
haafs,haars,habab,habbe,habet,habit,hable,habub,habus,hacek,hache,hacht,hacks,hacky,hadal,haddo,haded,hades,hadit,hadji,hadnt,hadst,haems,haets,hafis,hafiz,hafts,hagar,haggy,hagia,hague,haick,haida,haika,haikh,haiks,haiku,hails,haily,haine,haire,hairs,hairy,haiti,hajes,hajib,hajis,hajji,hakam,hakea,hakes,hakim,hakka,halal,halas,halch,haldu,haled,haler,hales,halfa,halfy,halid,halke,hallo,halls,halma,halms,haloa,halos,halse,halte,halts,halva,halve,halwe,hamal,haman,hamel,hames,hamli,hammy,hamsa,hamus,hamza,hanap,hance,hanch,hands,handy,hange,hangs,hanif,hanks,hankt,hanky,hanna,hanoi,hansa,hanse,hants,haole,haoma,haori,hapax,haply,happy,haram,haras,harbi,hards,hardy,hared,harem,hares,harim,harka,harks,harle,harls,harms,harns,harpa,harps,harpy,harre,harry,harsh,harst,harts,hasan,hasht,hashy,hasid,hasky,hasnt,hasps,hasta,haste,hasty,hatch,hated,hatel,hater,hates,hathi,hatte,hatti,hatty,haugh,hauld,haulm,hauls,hault,haunt,hausa,hause,haust,haute,havel,haven,haver,haves,havoc,hawed,hawer,hawks,hawky,hawok,hawse,haydn,hayed,hayer,hayes,hayey,hayne,hazan,hazed,hazel,hazen,hazer,hazes,hazle,hdqrs,heads,heady,heald,heals,heaps,heapy,heard,hears,heart,heath,heats,heave,heavy,heazy,heben,hecco,hecht,hecks,hecte,heder,hedge,hedgy,heeds,heedy,heels,heeze,heezy,hefts,hefty,heiau,heidi,heigh,heild,heils,heily,heinz,heirs,heist,heize,helas,helco,helen,helge,helio,helix,hello,hells,helly,helms,heloe,helot,helps,helve,hemad,hemal,heman,hemen,hemes,hemic,hemin,hemol,hemps,hempy,henad,hence,hendy,henen,henge,henna,henny,henry,hents,hepar,herat,herba,herbs,herby,herds,herem,heres,herls,herma,hermi,hermo,herms,herne,herns,heron,heros,herry,herse,hertz,herve,hests,heths,hetty,heuau,heuch,heugh,hevea,heved,hewed,hewel,hewer,hewgh,hexad,hexed,hexer,hexes,hexis,hexyl,heygh,hiant,hiate,hibla,hicht,hichu,hicks,hicky,hided,hidel,hider,hides,hield,hiems,hienz,hiera,highs,hight,higra,hijra,hiked,hiker,hikes,hilar,hilch,hilda,hillo,hills,hilly,hilsa,hilts,hilum,hilus,himne,hinau,hinch,hindi,hinds,hindu,hiney,hinge,hinny,hints,hiper,hipmi,hippa,hippi,hippo,hippy,hiram,hired,hiren,hirer,hires,hirse,hirst,hisis,hispa,hissy,hists,hitch,hithe,hived,hiver,hives,hoagy,hoard,hoars,hoary,hoast,hobby,hoboe,hobos,hocco,hocks,hocky,hocus,hodad,hoddy,hodge,hoers,hogan,hogen,hoggs,hoggy,hogni,hoick,hoise,hoist,hokan,hoked,hoker,hokes,hokey,hokku,hokum,holds,holed,holer,holes,holey,holia,holks,holla,hollo,holly,holms,holts,homam,homed,homer,homes,homey,homme,homos,honan,honda,hondo,honed,honer,hones,honey,hongs,honks,honky,honor,
honzo,hooch,hoods,hoody,hooey,hoofs,hoofy,hooka,hooks,hooky,hooly,hoops,hoose,hoosh,hoots,hoove,hooye,hopak,hoped,hoper,hopes,hopis,hoppo,hoppy,horae,horah,horal,horas,horde,horim,horla,horme,horns,horny,horol,horry,horse,horst,horsy,hosea,hosed,hosel,hosen,hoses,hosta,hosts,hotch,hotel,hotly,hotta,hough,hoult,hound,houri,hours,house,houss,housy,houve,hovel,hoven,hover,howdy,howea,howel,howes,howff,howfs,howks,howls,howso,hoyle,hsien,hsuan,huaca,huaco,huari,huave,hubba,hubby,hucho,hucks,huffs,huffy,huger,huile,hulas,hulch,hulks,hulky,hullo,hulls,human,humbo,humet,humic,humid,humin,humit,humor,humph,humps,humpy,humus,hunch,hundi,hunks,hunky,hunts,hurds,hurls,hurly,huron,hurri,hurry,hurst,hurts,hurty,husho,husht,husks,husky,hussy,hutch,hutia,hutre,huzza,huzzy,hybla,hydra,hydro,hyena,hying,hylas,hyleg,hylic,hymen,hymns,hynde,hyoid,hyped,hyper,hypes,hypha,hypho,hypos,hyrax,hyrse,hyrst,hyson,
iambe,iambi,iambs,ianus,iberi,ibota,icaco,icasm,iceni,ichor,ichth,icica,icier,icily,icing,icker,ickle,icons,iconv,ictic,ictus,idaho,idaic,idant,idcue,iddat,iddhi,iddio,ideal,idean,ideas,ident,idest,ideta,idgah,idiom,idion,idiot,idism,idist,idite,idled,idler,idles,idola,idols,idose,idryl,idyll,idyls,ierne,ifint,ifree,ifrit,igara,igdyr,ighly,igloo,iglus,ignaw,ignis,ihlat,ihram,iiasa,ijmaa,ijore,ikary,ikona,ikons,ilama,ileac,ileal,ileon,ileum,ileus,iliac,iliad,ilial,ilian,iliau,ilima,ilion,ilium,iller,illth,illus,iloko,image,imago,imams,imaum,imban,imbat,imbed,imber,imbue,imcnt,imide,imido,imids,imine,imino,immew,immis,immit,immix,immov,immun,impar,imped,impel,impen,imper,impis,imply,impot,imput,imshi,imvia,inact,inaja,inane,inapt,inark,inarm,inbow,inbye,incan,incas,incle,incog,incor,incra,incur,incus,incut,indan,indef,indew,index,india,indic,indii,indin,indiv,indol,indow,indra,indri,induc,indue,indus,indyl,inept,ineri,inerm,inert,ineye,infer,infin,infit,infix,infos,infra,ingan,ingem,inger,ingle,inglu,ingot,inial,inigo,inion,injun,inked,inken,inker,inket,inkie,inkle,inkos,inkra,inlaw,inlay,inlet,inmew,inned,inner,innet,inoma,inone,inorb,inorg,input,inrol,inrub,inrun,insea,insee,insep,inset,insol,instr,insue,intel,inter,intil,intnl,intra,intro,intsv,intue,inula,inure,inurn,inust,invar,invoy,inwit,iodal,iodic,iodid,iodin,iodol,ionic,iortn,iotas,iowan,iphis,irade,irani,iraqi,irate,irbis,irena,irene,ireos,irfan,irgun,irian,irido,iring,irish,irked,iroha,iroko,irone,irons,irony,irous,irpex,irred,irreg,irvin,irwin,isaac,isawa,isbas,iseum,isiac,ising,isize,islam,islay,isled,isles,islet,islot,ismal,isnad,isoln,isort,issei,issue,isthm,istle,itala,itali,italy,itchy,itcze,items,itemy,iters,ither,iulus,ivied,ivies,ivory,ivray,ixias,ixion,ixora,ixtle,izard,izars,izing,izote,iztle,izumi,izzat,
jabia,jabot,jabul,jacal,jacht,jacko,jacks,jacky,jacob,jaded,jades,jagat,jager,jaggs,jaggy,jagir,jagla,jagra,jagua,jahve,jails,jaime,jaina,jakes,jakey,jakob,jakos,jakun,jalap,jalee,jalet,jalop,jalor,jalur,jaman,jambe,jambo,jambs,james,jamie,jammy,janes,janet,janos,jantu,janty,janua,janus,japan,japed,japer,japes,japyx,jarde,jared,jarls,jarmo,jarra,jarry,jarvy,jasey,jason,jaspe,jatha,jatki,jatni,jatos,jauks,jaunt,jaups,javan,javas,javel,javer,jawab,jawan,jawed,jazey,jazzy,jeans,jeany,jebat,jebel,jebus,jeeps,jeers,jeery,jefes,jehad,jehup,jehus,jelab,jelib,jello,jells,jelly,jembe,jemez,jemmy,jenna,jenny,jerez,jerib,jerid,jerks,jerky,jerry,jesse,jests,jesus,jetes,jeton,jetty,jewed,jewel,jewis,jewry,jheel,jhool,jibba,jibbs,jibby,jibed,jiber,jibes,jiboa,jiffs,jiffy,jiggy,jihad,jills,jilts,jimbo,jimmy,jimpy,jingo,jingu,jinja,jinks,jinni,jinns,jinny,jiqui,jirga,jisms,jitro,jived,jives,jixie,jizya,jnana,jocko,jocks,jocum,jodel,joeys,johan,johns,joins,joint,joist,joked,joker,jokes,jokey,jokul,joles,jolly,jolts,jolty,jomon,jonah,jonas,jones,joola,joram,joree,jorge,jorum,josey,joshi,josie,josip,jotas,jotty,joual,jough,jougs,jouks,joule,journ,jours,joust,jowar,jowed,jowel,jower,jowls,jowly,jowpy,joyce,joyed,juang,juans,jubas,jubbe,jubes,jubus,judah,judas,judex,judge,judos,jufti,jufts,jugal,juger,jugum,juice,juicy,juise,jujus,juked,jukes,julep,jules,julia,julid,julie,julio,julus,jumba,jumbo,jumby,jumma,jumps,jumpy,junco,jundy,junks,junky,junta,junto,jupes,jupon,jural,jurat,jurel,juris,juror,jussi,justo,justs,jutes,jutic,jutka,jutty,juvia,juxta,juyas,
kaaba,kaama,kabab,kabar,kabel,kabob,kacha,kadis,kadmi,kados,kafir,kafiz,kafka,kafta,kagos,kagus,kahar,kahau,kaiak,kaifs,kails,kaimo,kains,kaiwi,kajar,kakan,kakar,kakas,kakis,kakke,kalam,kalan,kales,kalif,kalis,kalon,kalpa,kamao,kamas,kamba,kamel,kames,kamik,kamis,kanae,kanap,kanas,kanat,kande,kaneh,kanes,kanga,kanji,kannu,kansa,kanzu,kaons,kapai,kapas,kaphs,kapok,kappa,kappe,kapur,kaput,karat,karbi,karch,karel,karen,karez,karma,karns,karoo,karos,karou,karri,karst,karts,kaser,kasha,kashi,kaska,kassu,katar,katat,katha,kathy,katie,katik,katun,kauch,kauri,kaury,kavas,kaver,kayak,kayan,kayos,kazak,kazoo,keach,kearn,keats,keawe,kebab,kebar,kebby,kebob,kecks,kecky,kedar,kedge,kedgy,keech,keefs,keeks,keels,keena,keens,keeps,keest,keets,keeve,kefir,kefti,keirs,keist,keita,keith,keleh,kelek,kelep,kelia,kella,kelly,kelps,kelpy,kelts,kelty,kemal,kemps,kempt,kempy,kenaf,kenai,kench,kendo,kendy,kenno,kenny,kenos,kente,kenya,keout,kepis,kerat,kerbs,kerch,kerel,keres,kerfs,kerne,kerns,keros,kerri,kerry,kerve,keryx,kesar,kesse,ketal,ketch,keten,ketol,kette,ketty,ketyl,kevan,kevel,kever,kevil,kevin,kevyn,kexes,keyed,keywd,khadi,khair,khaja,khaki,khami,khans,khasa,khasi,khass,khats,khaya,kheda,khila,khmer,khoja,khoka,khond,khuai,khula,khuzi,khvat,kiaat,kiack,kiaki,kiang,kibei,kibes,kibla,kicks,kicky,kiddo,kiddy,kiefs,kiers,kieye,kikar,kikes,kikki,kikoi,kilah,kilan,kileh,kiley,kilij,kilim,kills,killy,kilns,kilom,kilos,kilts,kilty,kimbo,kimmo,kinah,kinch,kinds,kines,kings,kingu,kinic,kinin,kinks,kinky,kinoo,kinos,kinot,kioea,kioko,kiosk,kiowa,kippy,kirby,kirks,kirns,kirve,kisan,kishy,kisra,kissy,kists,kiswa,kitab,kitan,kitar,kited,kiter,kites,kithe,kiths,kitty,kivas,kiver,kiwai,kiwis,kiyas,kizil,klans,klaus,kleig,klick,klieg,kling,klino,klong,kloof,klops,klosh,kluck,klunk,klutz,kmole,knack,knape,knaps,knark,knarl,knars,knave,knead,kneed,kneel,knees,knell,knelt,knezi,kniaz,knick,knife,knish,knits,knive,knobs,knock,knoit,knoll,knops,knorr,knosp,knots,knout,knowe,known,knows,knurl,knurs,knute,knuth,knyaz,koala,koali,koans,koban,kobus,kodak,kodro,koels,koeri,kofta,kogai,kogia,kohen,kohls,kohua,koila,koine,kokam,kokan,kokia,kokil,kokio,kokos,kokra,kokum,kolas,kolea,kolis,kolos,kombu,konak,konde,kondo,kongo,kongu,konia,kooka,kooks,kooky,koorg,kopec,kopek,kophs,kopis,kopje,koppa,korah,korai,koran,korea,korec,korin,korma,koroa,korun,korwa,kosha,kosin,kosos,kotal,kotar,kotos,kotow,kouza,kovil,koyan,kraal,kraft,krait,krama,krang,krans,kraut,krebs,kreil,kreis,krems,kreng,krepi,krill,krina,kriss,krivu,krome,krona,
krone,kroon,krosa,krubi,kubba,kudos,kudus,kudzu,kufic,kugel,kukri,kukui,kulah,kulak,kulan,kuman,kumbi,kumis,kumni,kumyk,kumys,kunai,kunbi,kurku,kurmi,kurta,kurus,kusam,kusan,kusha,kusso,kusti,kusum,kutch,kutta,kvass,kvint,kwapa,kwela,kyack,kyang,kyars,kyats,kylie,kylin,kylix,kyloe,kyoto,kyrie,kytes,kythe,kyung,
laang,laban,labba,labby,label,labia,labis,labor,labra,lacca,laced,lacer,laces,lacet,lacey,lache,lacis,lacks,lacto,laded,laden,lader,lades,ladik,ladin,ladle,laeti,laevo,lagan,lagen,lager,lagly,lagna,lahar,laich,laics,laigh,laine,laird,lairs,lairy,laith,laity,laius,laked,laker,lakes,lakey,lakhs,lakie,lakin,lakke,laksa,lalls,lally,lamas,lamba,lambs,lamby,lamda,lamed,lamel,lamer,lames,lamia,lamin,lammy,lamna,lampf,lamps,lamus,lamut,lanai,lanao,lanas,lanaz,lance,lanch,lande,lands,lanes,laney,langi,lango,lanky,lanny,lansa,lanum,lapel,lapin,lapis,lapon,lappa,lapps,lapse,lapsi,larch,lards,lardy,lares,large,largo,largy,laria,larid,larin,larix,larks,larky,laron,larry,larum,larus,larva,larve,lased,laser,lases,lasso,lassu,lasts,lasty,latah,latax,latch,lated,laten,later,latex,lathe,lathi,laths,lathy,latin,latke,laton,latro,latus,lauan,laude,lauds,laugh,lauia,laund,laura,laure,laury,lautu,lavas,laved,laver,laves,lavic,lawed,lawks,lawns,lawny,lawzy,laxer,laxly,layed,layer,layia,layne,layup,lazar,lazed,lazes,leach,leads,leady,leafs,leafy,leaks,leaky,leans,leant,leany,leaps,leapt,learn,lears,leary,lease,leash,least,leath,leave,leavy,leban,leben,lebes,leche,leden,ledge,ledgy,ledol,ledum,leech,leeds,leeks,leeky,leers,leery,leese,leets,lefts,lefty,legal,leger,leges,legge,leggy,legis,legit,legoa,legua,lehay,lehrs,lehua,leigh,leila,leiss,leith,lekha,lelia,leman,lemel,lemma,lemna,lemon,lemur,lenad,lenca,lench,lends,lendu,lenes,lenin,lenis,lenny,lenos,lense,lenth,lento,leone,leora,lepal,lepas,leper,lepid,leppy,lepra,lepre,lepry,lepta,lepus,lerot,lerwa,lesed,lesgh,lesiy,lessn,leste,lesya,letch,lethe,lethy,letty,letup,leuch,leuco,leuds,leuma,leung,levee,level,leven,lever,levet,levin,levir,levis,lewie,lewis,lewth,lewty,lexia,lexic,lexis,lhota,liana,liane,liang,liard,liars,libby,libel,liber,libra,libre,libri,libya,licca,licet,lichi,licht,licit,licks,lidar,lidia,lidos,liege,liens,liers,liesh,liest,lieue,lieus,lieut,lieve,lifen,lifer,lifey,lifts,ligan,ligas,liger,ligge,light,ligne,liked,liken,liker,likes,likin,lilac,lilas,liles,lilly,lilts,liman,limas,limax,limba,limbi,limbo,limbs,limbu,limby,limed,limen,limer,limes,limey,limit,limli,limma,limmu,limns,limos,limps,limpy,limsy,linac,linch,linda,lindo,lindy,linea,lined,linen,liner,lines,linet,liney,linga,linge,lingo,lings,lingy,linha,linie,linin,linja,linje,links,linky,linne,linns,linon,linos,lints,linty,linum,linus,lions,lipan,lipic,lipid,lipin,lippy,lipse,liras,lirot,lisle,lisps,lists,listy,liszt,litai,litas,litch,liter,lites,lithe,lithi,litho,lithy,litra,litre,
litui,litus,lived,liven,liver,lives,livid,livor,livre,liwan,llama,llano,lloyd,lludd,loach,loads,loafs,loams,loamy,loans,loasa,loath,loave,lobal,lobar,lobby,lobed,lobes,lobos,lobus,local,loche,lochi,lochs,lochy,locks,locky,locos,locum,locus,loden,lodes,lodge,lodha,lodur,loeil,loess,lofts,lofty,logan,loges,loggy,logia,logic,logie,login,logis,logoi,logos,lohan,lohar,loins,lokao,loket,lolls,lolly,lomta,loner,longa,longe,longs,looby,looch,looed,looey,loofa,loofs,looie,looks,looky,looms,loons,loony,loope,loops,loopy,loord,loory,loose,loots,loped,loper,lopes,loppy,loral,loran,lords,lordy,lored,lorel,loren,lores,loric,loris,loros,lorry,lorum,losel,loser,loses,lossy,lotah,lotan,lotas,lotic,lotor,lotos,lotta,lotte,lotto,lotus,louch,louey,lough,louie,louis,loulu,loupe,loups,lourd,lours,loury,louse,lousy,louts,louty,lovat,loved,lovee,lover,loves,lovey,lowan,lowed,lower,lowes,lowly,lowry,lowse,lowth,loxed,loxes,loxia,loxic,loyal,lrecl,luaus,lubes,lubra,lucan,luces,lucet,lucia,lucid,lucks,lucky,lucre,luddy,luffa,luffs,luger,luges,luian,luigi,luite,lukan,lukas,luket,lulab,lulav,lulls,lully,lulus,lumen,lumme,lummy,lumps,lumpy,lumut,lunar,lunas,lunch,lunda,lunel,lunes,lunet,lunge,lungi,lungs,lungy,lunka,lunks,lunts,lupid,lupin,lupis,lupus,lural,lurch,lured,lurer,lures,lurid,lurks,lurky,lurry,luser,lushy,lusky,lusts,lusty,lusus,lutao,lutea,luted,luteo,luter,lutes,lutra,luxes,luxus,lyard,lyart,lyase,lycea,lycee,lycid,lycus,lydia,lyery,lygus,lying,lyken,lymph,lynch,lynne,lyres,lyric,lyrid,lysed,lyses,lysin,lysis,lysol,lyssa,lythe,lytic,lytta,
maana,maars,mabel,macan,macao,macaw,macco,maced,macer,maces,machi,macho,machs,macks,macle,macon,macro,madam,madge,madia,madid,madly,madoc,madre,mafey,mafia,mafic,mafoo,magas,mages,maggy,maghi,magic,magma,magna,magog,magot,magus,mahal,mahar,mahat,mahdi,mahoe,mahra,mahri,mahua,mahwa,maida,maids,maidu,maidy,maiid,maile,maill,mails,maims,maine,mains,maint,maire,mairs,maist,maius,maize,majas,major,majos,makah,makar,maker,makes,makos,makua,makuk,malam,malar,malax,malay,malee,maleo,males,malgr,malic,malie,malik,malls,malms,malmy,malta,malto,malts,malty,malum,malus,malva,malwa,mamas,mamba,mambo,mambu,mamey,mamie,mamma,mammy,mamry,manak,manal,manas,manba,mande,mandi,mands,maned,maneh,manei,manes,manet,maney,manga,mange,mangi,mango,mangy,mania,manic,manid,manie,manis,manit,maniu,manks,manky,manly,manna,manny,manoc,manor,manos,manqu,manse,manso,manta,manto,manty,manuf,manul,manus,maori,mapau,maple,mappy,maqui,marae,marah,maral,maras,maray,march,marci,marco,marcs,mardi,mardy,marek,mares,marga,marge,maria,marid,marie,mario,maris,marka,marko,marks,marla,marli,marls,marly,marok,maror,maros,marry,marse,marsh,marsi,marts,martu,marty,marvy,marys,masai,maser,masha,mashy,masks,mason,massa,masse,massy,masts,masty,matai,matar,matax,match,mated,mater,mates,matey,matha,mathe,maths,matie,matin,matka,matlo,matra,matsu,matta,matte,matti,matts,matty,matza,matzo,mauby,maugh,mauls,maund,mauri,mauts,mauve,maven,mavie,mavin,mavis,mawed,mawks,mawky,maxim,maxis,mayan,mayas,maybe,mayda,mayed,mayer,mayey,maynt,mayor,mayst,mazda,mazed,mazel,mazer,mazes,mazic,mazur,mazut,mbaya,mbira,mbori,mbuba,mccoy,mckay,meach,meads,meals,mealy,means,meant,meany,mease,meath,meats,meaty,meaul,mebos,mecca,mecon,mecum,medal,medea,media,medic,medii,medio,medle,medoc,meece,meech,meeds,meeks,meese,meeth,meets,meggy,meiji,meile,meiny,meith,melam,melas,melba,melch,melds,melee,meles,melia,melic,melis,mells,meloe,melon,melos,melts,memos,menad,menat,mende,mendi,mends,mendy,menic,menow,mensa,mense,mensk,menta,menus,meows,merak,merat,merce,merch,merci,mercy,mered,merel,merer,meres,merge,mergh,meril,merit,merks,merle,merls,merop,meros,merry,merse,mesad,mesal,mesas,mesel,mesem,meshy,mesic,mesne,meson,messe,messy,mesua,metad,metae,metal,metas,meted,metel,meter,metes,metho,meths,metic,metif,metin,metis,metol,metra,metre,metro,metus,metze,meuni,meuse,meute,mewed,mewer,mewls,mezzo,mhorr,miami,miaou,miaow,miasm,miaul,miauw,micah,micas,miche,micht,micks,micky,micra,micro,midas,middy,mider,midge,midgy,midis,midst,miens,miffs,miffy,miggs,might,miked,mikes,
mikey,mikie,mikir,mikra,milan,milch,miler,miles,milha,milia,milit,milko,milks,milky,milla,mille,mills,milly,milor,milos,milpa,milts,milty,mimed,mimeo,mimer,mimes,mimic,mimir,mimly,mimsy,mimus,mimzy,minae,minah,minar,minas,minbu,mince,mincy,minds,mined,miner,mines,minge,mingo,mingy,minie,minim,minis,minks,minny,minor,minos,minot,minow,mints,minty,minum,minus,miqra,mirac,mirak,mired,mires,mirex,mirid,mirks,mirky,mirly,mirth,mirvs,mirza,misce,misdo,miser,mises,misgo,misky,misly,misos,missa,missy,mists,misty,mitch,miter,mites,mitis,mitra,mitre,mitts,mitty,mitua,mixed,mixen,mixer,mixes,mixup,mizar,mizen,mizzy,mnage,mneme,mnium,moans,moats,mobby,mobed,mobil,moble,mocha,moche,mochy,mocks,mocoa,modal,model,modem,moder,modes,modge,modif,modoc,modus,moeck,moggy,mogos,mogul,mohar,mohel,mohos,mohur,mohwa,moier,moile,moils,moira,moire,moise,moism,moist,moity,mojos,mokes,mokum,molal,molar,molas,molds,moldy,moler,moles,molet,molge,molka,molla,molle,molls,molly,molpe,molto,molts,molvi,momes,momma,momme,mommy,momus,monad,monal,monas,monax,monde,mondo,monel,moner,money,mongo,monic,monie,monks,monny,monos,monte,month,montu,monty,mooch,moods,moody,mooed,moola,mools,moong,moons,moony,moore,moorn,moors,moory,moosa,moose,moost,mooth,moots,mopan,moped,moper,mopes,mopey,mopla,moppy,mopsy,mopus,moqui,morae,moral,moran,moras,morat,moray,mordu,mordv,morel,mores,morga,moric,morin,mormo,morne,morns,moroc,moron,moror,morph,morra,morro,morse,morth,morts,morus,mosan,mosel,moses,mosey,mosgu,mosks,mossi,mosso,mossy,moste,mosts,mosul,mosur,moted,motel,moter,motes,motet,motey,moths,mothy,motif,moton,motor,motte,motto,motts,motty,mouch,moudy,moues,mould,moule,mouls,moult,mouly,mound,mount,mourn,mouse,mousy,mouth,moved,mover,moves,movie,mowch,mowed,mower,mowha,mowie,mowra,mowse,mowth,moxas,moxie,moyen,moyle,mozos,mphps,mpret,msink,mster,mtier,muang,mucic,mucid,mucin,mucks,mucky,mucor,mucro,mucus,mudar,mudde,muddy,mudee,mudir,mudra,muffs,muffy,mufti,mufty,muggs,muggy,mugho,mugil,muhly,muist,mujik,mukri,mukti,mulch,mulct,muled,mules,mulet,muley,mulga,mulla,mulls,mulse,multi,multo,mumbo,mumms,mummy,mumps,mumsy,munch,munda,munga,munge,mungo,mungy,munia,munic,muntz,muong,muons,mural,muran,muras,murat,mured,mures,murex,murga,murid,murks,murky,murly,murmi,murph,murra,murre,murrs,murry,murut,murva,murza,musal,musar,musca,musci,mused,muser,muses,muset,musgu,musha,mushy,music,musie,musit,musks,musky,mussy,musth,musts,musty,mutch,muted,muter,mutes,mutic,mutts,mutus,muzzy,myall,mycol,mylar,mymar,mynah,mynas,myoid,myoma,myope,myops,
myopy,myron,myrrh,mysel,mysid,mysis,myths,
nabak,nabal,nabby,nabis,nabla,nable,nabob,nache,nacho,nacre,nacry,nadir,naevi,nagel,naggy,naght,nagor,nahor,nahua,nahum,naiad,naias,naifs,nails,naily,naira,nairy,naish,naive,naked,naker,nakir,nakoo,naled,namaz,nambe,namby,namda,named,namer,names,namma,nammo,nanas,nance,nancy,nanda,nandi,nandu,nanes,nanga,nanmu,nanny,nants,nantz,naomi,naoto,napal,napes,napoo,nappa,nappe,nappy,narco,narcs,nards,nardu,naren,nares,naric,naris,narks,narky,narra,nasab,nasal,nasat,nasch,nassa,nasty,nasua,nasus,natal,natch,nates,nathe,natty,natus,nauch,naumk,naunt,naval,navar,navel,naves,navet,navew,navig,navis,navvy,nawab,nawle,nawob,nayar,nazim,nazir,nazis,neaps,nears,neath,neats,nebby,nebel,necia,necks,necro,neddy,needn,needs,needy,neela,neeld,neele,neems,neeps,neese,neeze,nefas,neffy,neger,negro,negus,nehru,neifs,neigh,neist,nejdi,nelly,nemas,nemos,nenes,nenta,neons,neoza,nepal,neper,nepit,neral,nerds,nerka,nerol,nerts,nertz,nerve,nervy,nests,nesty,neter,netop,netts,netty,neuma,neume,neums,nevat,nevel,neven,never,neves,nevoy,nevus,newar,newel,newer,newly,newsy,newts,nexal,nexum,nexus,ngaio,ngapi,ngoko,ngoma,ngwee,niais,niall,niata,nibby,nicer,niche,nicht,nicks,nicky,nicol,nidal,nided,nides,nidge,nidor,nidus,niece,niels,niepa,nieve,nific,nifle,nifty,nigel,nighs,night,nigre,nigua,nihal,nihil,nikau,nikko,nikon,nills,nilot,nimbi,nines,ninja,ninny,ninon,ninos,ninox,ninth,nintu,ninut,niobe,niota,nipas,nippy,niris,nirls,nisan,nisei,nisse,nisus,nitch,niter,nitid,niton,nitos,nitre,nitro,nitta,nitty,niuan,nival,nixed,nixer,nixes,nixie,nixon,nizam,nizey,njave,nobby,nobel,nobis,noble,nobly,nobut,nocht,nocks,nodal,noddi,noddy,noded,nodes,nodus,noels,noemi,nogai,nogal,noggs,nohex,nohow,noils,noily,noint,noire,noise,noisy,nokta,nolle,nolos,nomad,nomap,nomas,nomen,nomes,nomic,nomoi,nomos,nonas,nonce,nonda,nondo,nones,nonet,nonic,nonly,nonny,nonya,nonyl,nooks,nooky,noons,noose,nopal,norah,noria,noric,norie,norit,norma,norms,norna,norry,norse,norsk,north,nosed,noser,noses,nosey,nosig,notal,notan,notch,noted,noter,notes,notre,notum,notus,nould,nouns,novae,novas,novel,novem,novum,novus,noway,nowch,nowed,nowel,nowts,noxal,noyau,npeel,nuadu,nubby,nubia,nucal,nucha,nucin,nuddy,nuder,nudes,nudge,nudie,nudum,nudzh,nugae,nukes,nullo,nulls,numac,numbs,numda,numen,numis,nummi,numps,numud,nunce,nunch,nunki,nunks,nunky,nunni,nunry,nuque,nurls,nurly,nurry,nurse,nursy,nutsy,nutty,nyala,nyaya,nydia,nylon,nymil,nymph,nymss,nyoro,nyssa,nyxis,
oadal,oaken,oakum,oared,oaric,oasal,oases,oasis,oasts,oaten,oater,oaths,oaves,obeah,obeli,obese,obeys,obias,obiit,obits,objet,oblat,obley,obmit,oboes,obole,oboli,obols,occas,occur,ocean,ocher,ochna,ochre,ochro,ochry,ocker,ocote,ocque,ocrea,octad,octal,octan,octet,octic,octyl,ocuby,oculi,ocyte,odder,oddly,odell,odeon,odeum,odist,odium,odoom,odors,odour,odyle,odyls,oecus,oelet,oenin,ofays,offal,offed,offer,offic,often,ofter,oftly,ogams,ogeed,ogees,ogham,oghuz,ogive,ogled,ogler,ogles,ogmic,ogres,ohare,ohelo,ohias,ohing,ohmic,ohone,oicks,oidia,oiled,oiler,oinks,oisin,okapi,okays,okehs,okras,okrug,olcha,olchi,olden,older,oldie,oleic,olein,olena,olent,oleos,olepy,oleum,olios,oliva,olive,ollas,ollav,ollie,ology,olona,olpae,olpes,olson,omaha,omani,omasa,omber,ombre,omega,omens,omers,omina,omits,omlah,omnes,omrah,oncer,onces,oncet,oncia,oncin,onery,onion,onium,onker,onkos,onlap,onlay,onmun,onset,ontal,ontic,onymy,oobit,oohed,oolak,oolly,oomph,oopak,oopod,oorie,ootid,oozed,oozes,oozoa,opahs,opals,opata,opelu,opens,opera,ophic,ophir,ophis,opine,oping,opium,opsin,opted,optic,orach,oracy,orage,orale,orals,orang,orans,orant,oraon,orary,orate,orbed,orbic,orbit,orcas,orcin,order,ordos,oread,oreas,orgal,organ,orgia,orgic,orgue,orias,oribi,oriel,orion,oriya,orkey,orles,orlet,orlon,orlop,orlos,ormer,ornes,ornis,oromo,orpin,orpit,orris,orrow,orsel,orson,ortet,ortho,ortol,ortyx,orvet,oryza,osage,osaka,oscan,oscar,oscin,osela,oshac,oshea,oside,osier,oskar,osmic,osmin,osmol,osone,ossal,ossea,osset,ossia,ostia,ostic,otary,otate,other,othin,otium,otkon,otomi,ottar,otter,ottos,otyak,ouabe,ought,ouija,oukia,oulap,ounce,ounds,oundy,ouphe,ouphs,ourie,ousel,ousia,ousts,outas,outby,outdo,outed,outen,outer,outgo,outly,outre,ouvre,ouzel,ouzos,ovals,ovant,ovary,ovate,ovens,overs,overt,ovest,ovile,ovine,ovism,ovist,ovoid,ovoli,ovolo,ovula,ovule,owght,owing,owler,owlet,owned,owner,owsen,owser,oxane,oxbow,oxboy,oxeye,oxfly,oxide,oxids,oxime,oxims,oxlip,oxman,oxter,oyana,oyers,oylet,ozark,ozena,ozias,ozone,
paauw,pablo,pacas,pacay,paced,pacer,paces,pacha,pacht,packs,pacos,pacta,pacts,padda,paddy,padge,padle,padou,padre,padri,padus,paean,paeon,pagan,paged,pager,pages,pagne,pagod,pagus,pahmi,pahos,paiks,pails,paine,pains,paint,pairs,pairt,paisa,paise,palar,palas,palau,palay,palch,palea,paled,paler,pales,palet,palew,palis,palki,palla,palli,palls,pallu,pally,palma,palmo,palms,palmy,palpi,palps,palsy,palta,palus,pamhy,pamir,pampa,panak,panax,panda,pandy,paned,panel,panes,panga,pangi,pangs,panic,panna,panne,panos,panse,pansy,panto,pants,panty,panus,paola,paolo,papal,papas,papaw,paper,papey,papio,pappi,pappy,papua,papyr,paque,parah,param,parao,paras,parch,parde,pardi,pardo,pards,pardy,pared,parel,paren,parer,pares,pareu,parge,pargo,paris,parka,parks,parky,parle,parli,parly,parma,parol,parra,parrs,parry,parse,parsi,parte,parti,parto,parts,party,parus,parve,pasan,pasch,paseo,pases,pasha,pashm,pasis,pasmo,passe,passo,passu,pasta,paste,pasts,pasty,pasul,patao,patas,patch,pated,patee,patel,paten,pater,pates,paths,pathy,patia,patin,patio,patly,patsy,patta,patte,pattu,patty,pauky,paula,pause,pauxi,pavan,paved,paven,paver,paves,pavia,pavid,pavin,pavis,pawaw,pawed,pawer,pawky,pawls,pawns,paxes,payed,payee,payen,payer,payni,payor,pbxes,peace,peach,peage,peags,peaks,peaky,peals,peans,pearl,pears,peart,pease,peasy,peats,peaty,peavy,peban,pecan,pechs,pecht,pecks,pecky,pecos,pedal,pedee,pedes,pedro,pedum,peeke,peeks,peele,peels,peens,peeoy,peeps,peepy,peers,peert,peery,peeve,peggy,pegma,peine,peins,peise,peize,pekan,pekes,pekin,pekoe,peles,pelew,pelfs,pelon,pelta,pelts,penal,pence,penda,pendn,pends,penes,pengo,penis,penna,penni,penny,pense,pensy,penta,penup,peons,peony,pepla,pepos,peppy,pepsi,perai,perau,perca,perch,percy,perdu,perdy,peres,peril,peris,perit,perks,perky,perla,perle,perms,perry,perse,perty,perun,pesah,pesky,pesos,peste,pests,petal,peter,petit,petos,petre,petri,petro,petti,petto,petty,petum,peuhl,pewee,pewit,pflag,pfund,pgntt,phaca,phaet,phage,phane,phano,phare,pharm,pharo,phase,phasm,pheal,phebe,phene,pheny,pheon,phial,phies,phill,phlox,phoby,phoca,phoma,phone,phono,phons,phony,phora,phose,phoss,photo,phots,phpht,phren,phyla,phyle,phyma,physa,piaba,piala,piano,pians,piast,pibal,picae,pical,picas,picea,pichi,picks,picky,picot,picra,picry,picul,picus,pidan,piece,piend,piers,piert,piest,pieta,piete,piety,piezo,piggy,pight,pigly,pigmy,piing,pikas,piked,pikel,piker,pikes,pikey,pikle,pilaf,pilar,pilau,pilaw,pilch,pilea,piled,pilei,piler,piles,pilin,pilis,pills,pilmy,pilon,pilot,pilum,pilus,piman,
pimas,pimps,pinal,pinas,pinax,pinch,pinda,pindy,pined,piner,pines,piney,pinge,pingo,pings,pinic,pinko,pinks,pinky,pinna,pinny,pinon,pinot,pinta,pinte,pinto,pints,pinup,pinus,pinyl,pions,piotr,pious,pioxe,pipal,piped,piper,pipes,pipet,pipey,pipid,pipil,pipit,pippy,pipra,pique,pirns,pirny,pirog,pirol,pirot,pisan,pisay,pisco,pishu,pisky,piste,pisum,pitas,pitau,pitch,piths,pithy,piton,pitta,piuri,piute,pivot,piwut,pixel,pixes,pixie,pizza,place,plack,plaga,plage,plaid,plain,plait,plane,plang,plank,plans,plant,plash,plasm,plass,plate,plato,plats,platt,platy,plaud,playa,plays,plaza,plead,pleas,pleat,plebe,plebs,pleck,pleis,plena,pleny,pleon,plica,plied,plier,plies,plink,pliny,pliss,ploat,ploce,plock,plods,plomb,plonk,plook,plops,plote,plots,plott,plotx,plouk,plout,plows,ploys,pluck,pluff,plugs,pluma,plumb,plume,plump,plums,plumy,plunk,plupf,plush,pluto,plyer,pneum,poach,pobby,pocan,poche,pocks,pocky,pocul,pocus,podal,poddy,podex,podge,podgy,podia,podos,poems,poesy,poets,pogey,pogge,poggy,pohna,poilu,poind,point,poire,poise,pokan,poked,poker,pokes,pokey,pokie,pokom,polab,polar,poled,poler,poles,poley,polio,polis,polit,polje,polka,polki,polls,polly,poloi,polos,polyp,polys,pomak,pombe,pombo,pomel,pomes,pomey,pomme,pommy,pompa,pomps,ponca,ponce,pondo,ponds,pondy,pones,poney,ponga,pongo,ponja,ponos,ponto,pooch,poods,poohs,pooka,pooli,pools,pooly,poons,poops,poori,poort,pooty,poove,popal,popes,popie,poppa,poppy,popsy,poral,porch,pored,porer,pores,poret,porge,porgo,porgy,poria,porks,porky,porno,porns,poros,porry,porta,porte,porto,ports,porty,porus,posca,posed,poser,poses,posey,posho,posit,posse,possy,posts,potch,poter,potoo,potsy,potti,potto,potty,potus,pouce,pouch,poucy,pouff,poufs,poule,poulp,poult,pound,pours,pousy,pouts,pouty,powan,power,powny,poxed,poxes,poyou,pozzy,praam,prado,prahm,prahu,prams,prana,prand,prang,prank,praos,prase,prate,prats,pratt,praus,prawn,praya,prays,predy,preed,preen,prees,prela,prepd,prepg,prepn,preps,presa,prese,press,prest,preta,preux,preve,prexy,preys,priam,price,prich,prick,pricy,pride,pridy,pried,prier,pries,prigs,prill,prima,prime,primi,primo,primp,prims,primy,prine,prink,print,prion,prior,prise,prism,priss,prius,privy,prize,proal,proas,probe,prodd,prods,proem,profs,progs,proke,prole,promo,proms,prone,prong,proof,propr,props,prore,prose,proso,pross,prost,prosy,prote,proto,proud,prove,prowl,prows,proxy,prude,prudy,prune,prunt,pruta,pryer,pryse,psalm,psend,pseud,pshav,pshaw,psize,psoae,psoai,psoas,psora,psych,pubal,pubes,pubic,pubis,puces,pucka,pucks,pudda,puddy,
pudge,pudgy,pudic,pudsy,puffs,puffy,puget,puggi,puggy,pugil,puist,puked,puker,pukes,pukka,pulas,puled,puler,pules,pulex,pulik,pulis,pulka,pulli,pulls,pulps,pulpy,pulse,pumas,pumex,pumps,punan,punas,punce,punch,punct,punga,pungi,pungs,pungy,punic,punka,punks,punkt,punky,punny,punta,punti,punto,punts,punty,pupae,pupal,pupas,pupil,puppy,purau,purda,purdy,pured,puree,purer,purey,purga,purge,purim,purin,puris,purls,purre,purrs,purry,purse,pursy,purty,puses,pushy,pussy,putid,puton,putti,putto,putts,putty,pyche,pygal,pygmy,pyins,pylar,pylic,pylon,pynot,pyoid,pyral,pyran,pyres,pyrex,pyric,pyrus,pyxes,pyxie,pyxis,
qaids,qanat,qatar,qiana,qibla,qiyas,qophs,quack,quadi,quads,quaff,quags,quail,quais,quake,quaky,quale,qualm,quant,quare,quark,quarl,quart,quash,quasi,quass,quata,quate,quauk,quave,quawk,quays,qubba,queak,queal,quean,queen,queer,queet,quegh,quell,quelt,queme,quent,querl,quern,query,quest,queue,queys,quica,quick,quids,quiet,quiff,quila,quill,quilt,quina,quink,quins,quint,quipo,quips,quipu,quira,quire,quirk,quirl,quirt,quist,quite,quito,quits,quitu,quoad,quods,quoin,quoit,quota,quote,quoth,quott,qursh,qurti,
raash,rabal,rabat,rabbi,rabic,rabid,rabin,rabot,raced,racer,races,rache,racks,racon,radar,radek,radii,radio,radix,radly,radon,raffe,raffs,rafik,rafts,rafty,ragas,raged,ragee,rager,rages,raggy,raghu,ragis,rahul,raiae,raias,raids,rails,rains,rainy,raise,rajab,rajah,rajas,rajes,rajiv,rakan,raked,rakee,raker,rakes,rakis,rakit,rales,rally,ralph,ramal,raman,rambo,ramed,ramee,ramet,ramex,ramie,rammi,rammy,ramon,ramps,ramta,ramus,ranal,rance,ranch,randn,rands,randy,ranee,range,rangy,ranid,ranis,ranks,ranli,ranny,rants,ranty,raped,raper,rapes,raphe,rapic,rapid,rappe,rarer,rased,rasen,raser,rases,rason,rasps,raspy,rasse,rasty,ratal,ratan,ratch,rated,ratel,rater,rates,ratha,rathe,ratio,ratos,ratti,ratty,ratwa,rauli,raupo,raved,ravel,raven,raver,raves,ravin,rawer,rawin,rawky,rawly,raxed,raxes,rayah,rayan,rayas,rayat,rayed,rayon,razed,razee,razer,razes,razoo,razor,reaal,reach,react,readd,readl,reads,ready,reaks,realm,reals,reams,reamy,reaps,rearm,rears,reask,reast,reasy,reata,reave,rebab,rebag,reban,rebar,rebbe,rebec,rebed,rebeg,rebel,rebia,rebid,rebob,rebop,rebox,rebud,rebus,rebut,rebuy,recap,recce,recco,reccy,recip,recit,recks,recon,recpt,recta,recti,recto,recur,recut,redan,redds,reddy,reded,redes,redia,redid,redig,redip,redly,redos,redox,redry,redub,redue,redug,redux,redye,reeds,reedy,reefs,reefy,reeks,reeky,reels,reese,reesk,reest,reeve,refan,refed,refel,refer,reffo,refit,refix,refly,refry,regal,regel,reges,reget,regga,regia,regie,regin,regle,regma,regna,regur,rehem,rehid,rehoe,reice,reich,reifs,reify,reign,reina,reink,reins,reist,reive,rejig,rekey,relap,relax,relay,reles,relet,relic,relig,relit,relot,reman,remap,remen,remet,remex,remit,remix,remop,remue,remus,renal,renay,rends,rendu,reneg,renes,renet,renew,renga,renig,renin,renky,renne,rente,rents,reoil,reown,repad,repas,repay,repeg,repel,repen,repew,repic,repin,reply,repot,repps,repro,repry,reran,reree,rerig,rerob,rerow,rerub,rerun,resat,resaw,resay,resee,reset,resew,resex,resid,resin,resit,resow,restr,rests,resty,resue,resun,resup,retag,retal,retan,retar,retax,retch,retem,rethe,retia,retie,retin,retip,retro,retry,reuel,reune,reuse,revay,revel,rever,revet,revie,revue,rewan,rewax,rewed,rewet,rewin,rewon,rexen,rexes,rfree,rhamn,rheae,rheas,rheda,rheen,rheic,rhein,rhema,rheme,rheum,rhila,rhina,rhine,rhino,rhoda,rhoeo,rhomb,rhumb,rhyme,rhymy,rhyta,rials,riant,riata,ribat,ribby,ribes,riced,ricer,rices,ricey,riche,richt,ricin,ricks,ricky,riden,rider,rides,ridge,ridgy,riels,rifer,riffi,riffs,rifle,rifts,rifty,rigel,right,rigid,rigol,rigor,riled,
riles,riley,rille,rills,rilly,rimal,rimas,rimed,rimer,rimes,rimpi,rinch,rinde,rinds,rindy,ringe,rings,ringy,rinka,rinks,rinse,riots,ripal,riped,ripen,riper,ripes,ripup,risen,riser,rises,rishi,risks,risky,risqu,risus,rites,rithe,ritsu,ritus,ritzy,rival,rived,rivel,riven,river,rives,rivet,riyal,rizar,roach,roads,roams,roans,roars,roast,robed,rober,robes,robin,roble,robot,robur,roche,rocks,rocky,rocta,rodeo,rodge,rogan,roger,rogue,roguy,rohan,rohob,rohun,roils,roily,roist,rojak,rokee,roker,rokey,roleo,roles,rolfe,rollo,rolls,romal,roman,romeo,romic,romps,rompu,rompy,ronco,ronde,rondo,ronga,ronin,ronni,roods,rooed,roofs,roofy,rooks,rooky,rooms,roomy,roosa,roose,roost,rooti,roots,rooty,roove,roped,roper,ropes,ropey,roque,roral,roric,rorid,rorty,rosal,rosed,rosel,roses,roset,roshi,rosin,rotal,rotan,rotas,rotch,roter,rotes,rotge,rotls,rotor,rotos,rotse,rotta,rotte,rouen,roues,rouge,rough,rougy,rouky,round,roups,roupy,rouse,roust,route,routh,routs,roved,roven,rover,roves,rovet,rowan,rowdy,rowed,rowel,rowen,rower,rowet,rowte,rowth,rowty,roxie,royal,royet,royou,rozum,ruach,ruana,rubby,rubes,rubia,rubin,ruble,rubor,rubus,ruche,rucks,rucky,rudas,rudds,ruddy,ruder,rudge,ruely,ruers,ruffe,ruffs,rufus,rugae,rugal,rugby,ruggy,ruing,ruins,ruled,ruler,rules,rumal,ruman,rumba,rumbo,rumen,rumex,rumly,rummy,rumor,rumps,rumpy,runby,runch,rundi,runed,runer,runes,rungs,runic,runny,runsy,runts,runty,rupee,rupia,rupie,rural,ruses,rushy,rusin,rusks,rusky,rusma,rusot,russe,rusts,rusty,rutch,ruths,rutic,rutin,rutty,rutyl,ruvid,rybat,ryder,ryked,rykes,rynds,ryots,
sabal,saban,sabby,sabed,saber,sabes,sabia,sabik,sabin,sabir,sable,sably,sabot,sabra,sabre,sabzi,sacae,sacks,sacra,sacre,sacro,sacry,sades,sadhe,sadhu,sadic,sadie,sadis,sadly,saeta,safar,safen,safer,safes,sagai,sagan,sagas,sager,sages,saggy,sagos,sagra,sagum,sahib,sahme,saice,saidi,saids,saify,saiga,saiid,sails,saily,saimy,sains,saint,saiph,sairy,saite,saith,saiva,sajou,sakai,sakel,saker,sakes,sakha,sakis,sakti,salad,salal,salar,salat,salay,salem,salep,sales,salet,salic,salix,salle,sally,salma,salmi,salmo,salol,salon,salpa,salps,salsa,salse,salta,salts,salty,salud,salue,salus,salva,salve,salvo,salvy,samaj,samal,saman,samas,samba,sambo,samek,samel,samen,samir,sammy,samoa,sampi,samps,sanai,sanct,sancy,sands,sandy,saned,saner,sanes,sanga,sangh,sangu,sanit,sanka,sansi,santa,santo,santy,sapan,sapek,sapid,sapin,sapit,saple,sapor,sappy,saqib,saraf,sarah,saran,sards,saree,sarge,sargo,sarif,sarin,sarip,saris,sarks,sarky,sarna,sarod,saron,saros,sarpo,sarra,sarsa,sarsi,saruk,sarum,sarus,sasan,sasin,sasse,sassy,satai,satan,sated,satem,sates,satin,satis,satyr,sauba,sauce,sauch,saucy,saudi,saugh,sauld,sauls,sault,sauna,saunt,saura,saury,saute,sauty,sauve,saved,saver,saves,savey,savin,savor,savoy,savvy,sawah,sawan,sawed,sawer,sawny,saxes,saxon,sayal,sayee,sayer,sayid,sayst,sazen,scabs,scads,scaff,scags,scala,scald,scale,scalf,scall,scalp,scalt,scalx,scaly,scalz,scamp,scams,scans,scant,scape,scare,scarf,scarn,scarp,scars,scart,scary,scase,scats,scatt,scaul,scaum,scaup,scaur,scaut,scawd,scawl,sceat,scelp,scena,scend,scene,scent,schav,schiz,schmo,schuh,schul,schwa,scian,scind,scion,sciot,sclat,sclav,sclaw,scler,sclim,scoad,scobs,scoff,scoke,scolb,scold,scomm,scone,scoon,scoop,scoot,scopa,scope,scops,score,scorn,scote,scots,scott,scouk,scoup,scour,scout,scove,scovy,scowl,scows,scrab,scrae,scrag,scram,scran,scrap,scrat,scraw,scray,scree,screw,scrim,scrin,scrip,scrit,scrob,scrod,scrog,scroo,scrow,scrub,scruf,scrum,scuba,scudi,scudo,scuds,scuff,scuft,sculk,scull,sculp,scult,scums,scups,scurf,scuse,scuta,scute,scuts,scyld,scyth,sdump,seals,sealy,seams,seamy,sears,seary,seats,seave,seavy,sebat,sebum,secco,secno,secos,secre,sects,secus,sedan,sedat,seder,sedge,sedgy,sedum,seech,seeds,seedy,seege,seeks,seels,seely,seems,seenu,seeps,seepy,seers,segar,seggy,segni,segno,segol,segos,segou,segue,sehyo,seige,seine,seise,seism,seity,seize,sekar,seker,sekos,selah,selfs,sella,selle,selli,sells,selly,selva,semee,semel,semen,semes,semic,semih,semis,senal,senam,sence,senci,sends,senex,sengi,senit,senna,senor,sensa,sense,
senso,sensu,senti,sents,senvy,senza,seora,seoul,sepad,sepal,sepia,sepic,sepoy,seppa,septa,septi,septs,seqed,sequa,seqwl,serab,serac,serai,seral,serau,seraw,sered,sereh,serer,seres,serfs,serge,sergt,seric,serif,serin,serio,sermo,seron,serow,serra,serry,serta,serum,serut,serve,servo,sesia,sesma,sessa,sesti,setae,setal,seton,setup,seugh,seven,sever,sevum,sewan,sewar,sewed,sewen,sewer,sewin,sexed,sexes,sexly,sexto,sexts,sfoot,sfree,shack,shade,shado,shads,shady,shaft,shags,shahi,shahs,shaka,shake,shako,shaku,shaky,shale,shall,shalt,shaly,shama,shame,shams,shane,shang,shank,shant,shape,shaps,shapy,shard,share,shari,shark,sharn,sharp,shaul,shaup,shave,shawl,shawm,shawn,shaws,shawy,shays,sheaf,sheal,shean,shear,sheas,sheat,sheds,shedu,sheel,sheen,sheep,sheer,sheet,sheik,shela,sheld,shelf,shell,shema,shemu,shend,sheng,shent,sheol,sherd,sheth,sheva,shewa,shewn,shews,shiah,shiai,shice,shick,shide,shied,shiel,shier,shies,shift,shiko,shilf,shilh,shill,shily,shims,shina,shine,shins,shiny,ships,shipt,shire,shirk,shirl,shirr,shirt,shish,shisn,shist,shita,shits,shiva,shive,shivs,shivy,shlep,shluh,shoad,shoal,shoat,shock,shode,shoed,shoer,shoes,shogi,shogs,shoji,shojo,shola,shole,shona,shone,shood,shooi,shook,shool,shoon,shoop,shoor,shoos,shoot,shope,shops,shore,shorl,shorn,short,shote,shots,shott,shout,shove,showd,shown,shows,showy,shoya,shoyu,shrab,shraf,shrag,shram,shrap,shred,shree,shrew,shrip,shris,shrog,shrub,shrug,shuba,shuck,shuff,shuln,shuls,shune,shuns,shunt,shure,shurf,shush,shute,shuts,shyam,shyer,shyly,siafu,sials,sibbs,sibby,sibyl,sicca,sicel,sicer,sices,sicht,sicks,sicle,sided,sider,sides,sidhe,sidia,sidle,sidth,siege,siena,siest,sieur,sieva,sieve,sievy,sifac,sifts,sighs,sight,sigil,sigla,sigma,signa,signs,sikar,siker,sikes,siket,sikhs,sikra,silas,silds,silen,silex,silks,silky,sills,silly,silos,silts,silty,silva,silyl,simal,simar,simas,simba,simia,simon,simps,simul,sinae,sinal,since,sines,sinew,singe,singh,sings,sinhs,sinic,sinks,sinky,sinon,sinto,sintu,sinus,sioux,siped,siper,sipes,sipid,sippy,sired,siree,siren,sires,sirex,sirih,siris,sirki,sirky,siroc,sirop,siros,sirra,sirup,sisal,sisel,sises,sissu,sissy,sitao,sitar,sitch,sited,sites,sithe,sitio,sitka,sitta,situp,situs,siums,siusi,sivan,siver,siwan,sixer,sixes,sixmo,sixte,sixth,sixty,sizal,sizar,sized,sizer,sizes,sjaak,skaff,skags,skail,skair,skald,skart,skate,skats,skean,skeat,skeed,skeeg,skeel,skeen,skeer,skees,skeet,skegs,skeif,skein,skelf,skell,skelp,skemp,skene,skeps,skere,skers,skete,skewl,skews,skewy,skice,skidi,skids,skied,
skier,skies,skiey,skiff,skift,skiis,skill,skime,skimo,skimp,skims,skink,skins,skint,skips,skirl,skirp,skirr,skirt,skite,skits,skive,skivy,skiwy,skoal,skoot,skout,skuas,skulk,skull,skulp,skunk,skuse,skyed,skyey,skyre,skyte,slabs,slack,slade,slags,slain,slait,slake,slaky,slamp,slams,slane,slang,slank,slant,slape,slaps,slare,slart,slash,slask,slate,slath,slats,slaty,slaum,slave,slavi,slavs,slaws,slays,sleck,sleds,sleek,sleep,sleer,sleet,slent,slept,slete,slews,sleys,slice,slich,slick,slide,slier,slily,slime,slims,slimy,sline,sling,slink,slipe,slips,slipt,slirt,slish,slite,slits,slive,sloan,sloat,slobs,slock,sloes,slogs,sloid,slojd,sloka,sloke,slone,slonk,sloom,sloop,sloot,slope,slops,slopy,slorp,slosh,slote,sloth,slots,slour,slows,sloyd,slubs,slued,sluer,slues,sluff,slugs,sluig,sluit,slump,slums,slung,slunk,slurb,slurp,slurs,slush,sluts,slyer,slyly,slype,smack,smaik,small,smalm,smalt,smarm,smart,smash,smaze,smear,smeek,smeer,smell,smelt,smerk,smeth,smews,smich,smift,smile,smily,smirk,smite,smith,smock,smogs,smoke,smoko,smoky,smolt,smook,smoos,smoot,smore,smote,smous,smout,smrgs,smurr,smuse,smush,smuts,smyth,snack,snaff,snafu,snags,snail,snake,snaky,snape,snaps,snapy,snare,snark,snarl,snary,snash,snast,snath,snaws,snead,sneak,sneap,sneck,sneds,sneer,snell,snerp,snibs,snick,snide,snies,sniff,snift,snigs,snipe,snips,snipy,snirl,snirt,snite,snits,snitz,snivy,snobs,snock,snoek,snoga,snoke,snood,snook,snool,snoop,snoot,snore,snork,snort,snots,snout,snowk,snowl,snows,snowy,snubs,snuck,snuff,snugs,snurl,snurp,snurt,snyed,snyes,soaks,soaky,soapi,soaps,soapy,soars,soary,soave,sobby,sober,socht,socii,socko,socks,socky,socle,sodas,soddy,sodic,sodio,sodom,sofar,sofas,sofer,sofia,softa,softs,softy,soger,soget,soggy,soign,soils,soily,sojas,soken,sokes,solan,solar,solay,soldi,soldo,solea,soled,solen,soler,soles,solfa,solid,solio,solod,solon,solos,solum,solus,solve,somal,somas,somet,somma,somne,sonar,soncy,sonde,sones,songo,songs,songy,sonic,sonja,sonly,sonny,sonsy,sooey,sooke,sooky,soony,soord,sooth,soots,sooty,sophs,sophy,sopor,soppy,soral,soras,sorbs,sorda,sordo,sords,soree,sorel,sorer,sores,sorex,sorgo,
sorns,sorra,sorry,sorts,sorty,sorus,sorva,sosia,sosie,soter,sotho,soths,sotie,sotik,sotol,sough,souls,soulx,souly,soulz,sound,soups,soupy,sourd,sours,soury,souse,south,sowan,sowar,sowed,sowel,sower,sowle,sowse,sowte,soyas,soyot,sozin,sozly,spaad,space,spack,spacy,spade,spado,spaed,spaer,spaes,spahi,spaid,spaik,spail,spain,spair,spait,spake,spald,spale,spall,spalt,spane,spang,spank,spann,spans,spare,spark,sparm,spars,spart,spary,spasm,spass,spate,spath,spats,spave,spawl,spawn,spays,speak,speal,spean,spear,spece,speck,specs,spect,speed,speel,speen,speer,speil,speir,spekt,spelk,spell,spelt,spend,spent,speos,spere,sperm,spete,spews,spewy,sphex,spial,spica,spice,spick,spics,spicy,spied,spiel,spier,spies,spiff,spike,spiks,spiky,spile,spill,spilt,spina,spine,spink,spins,spiny,spira,spire,spiro,spirt,spiry,spise,spiss,spite,spits,spitz,spivs,splad,splat,splay,splet,split,spock,spode,spoil,spoke,spoky,spole,spong,spoof,spook,spool,spoom,spoon,spoor,spoot,spore,sport,sposh,spots,spout,sprad,sprag,sprat,spray,spree,spret,sprew,sprig,sprit,sprod,sprot,sprue,sprug,spuds,spued,spues,spuke,spume,spumy,spung,spunk,spurl,spurn,spurs,spurt,sputa,spute,spyer,squab,squad,squam,squat,squaw,squeg,squet,squib,squid,squin,squit,squiz,sruti,ssing,ssort,sstor,staab,stabs,stacc,stack,stacy,stade,staff,stage,stags,stagy,staia,staid,staig,stail,stain,staio,stair,stake,stale,stalk,stall,stamp,stand,stane,stang,stank,staph,stare,stark,starn,starr,stars,start,starw,stary,stash,state,stats,stauk,staun,staup,stave,stawn,stays,stchi,stead,steak,steal,steam,stean,stech,steed,steek,steel,steem,steen,steep,steer,stegh,steid,stein,stela,stele,stell,stema,stems,stend,steng,steno,stent,steps,stept,stere,steri,sterk,stern,stero,stert,stets,steve,stews,stewy,stich,stick,stied,sties,stife,stiff,stilb,stile,still,stilt,stime,stimy,stine,sting,stink,stint,stion,stipa,stipe,stipo,stire,stirk,stirp,stirs,stite,stith,stive,stivy,stoae,stoai,stoas,stoat,stobs,stock,stoep,stoff,stoga,stogy,stoic,stoit,stoke,stola,stold,stole,stoma,stomp,stond,stone,stong,stonk,stony,stood,stoof,stook,stool,stoon,stoop,stoot,stopa,stope,stops,stopt,store,stork,storm,story,stosh,stoss,stott,stoun,stoup,stour,stout,stove,stowp,stows,strad,strae,strag,stram,strap,straw,stray,stree,strep,stret,strew,strey,stria,strid,strig,strip,strit,strix,strom,strop,strow,stroy,strub,strue,strum,strut,struv,stubb,stube,stubs,stuck,stude,studs,study,stuff,stull,stulm,stump,stums,stung,stunk,stuns,stunt,stupa,stupe,stupp,sturk,sturt,stuss,styan,styca,styed,styes,style,
styli,stylo,stymy,suade,suant,suave,subah,subas,subch,suber,subet,subra,subst,succi,sucks,sucre,sudan,sudds,suddy,sudes,sudic,sudor,sudra,sudsy,suede,suent,suers,suets,suety,sueve,suevi,sugan,sugar,sugat,sughs,sugih,sugis,suina,suine,suing,suint,suist,suite,suits,suity,sukey,sulci,sulea,sulfa,sulfo,sulka,sulks,sulky,sulla,sully,sumac,sumak,sumen,summa,sumos,sumph,sumps,sumpt,sunil,sunna,sunni,sunns,sunny,sunup,suomi,supai,super,supes,suppl,supra,supvr,surah,sural,suras,surat,surds,sured,surer,sures,surfs,surfy,surge,surgy,surly,surma,surra,surya,susan,sushi,susie,susso,sussy,sutor,sutra,sutta,suyog,suzan,svelt,swabs,swack,swage,swags,swail,swain,swale,swami,swamp,swamy,swang,swank,swans,swape,swaps,sward,sware,swarf,swarm,swart,swash,swath,swati,swats,sways,swazi,sweal,swear,sweat,swede,sweep,sweer,sweet,swego,swell,swelp,swelt,swept,swerd,swick,swift,swigs,swile,swill,swims,swimy,swine,swing,swink,swipe,swipy,swird,swire,swirl,swish,swiss,swith,swive,swizz,swobs,swoln,swonk,swoon,swoop,swops,sword,swore,sworn,swosh,swots,swoun,swung,swure,sybil,sybow,sycee,syces,sycon,syftn,sykes,sylid,sylph,sylva,synch,syncs,synod,synop,syren,syria,syrma,syrup,syrus,sysin,
taata,tabac,tabby,tabel,taber,tabes,tabet,tabic,tabid,tabis,tabla,table,tabog,taboo,tabor,tabus,tabut,tacan,tacca,taces,tacet,tache,tachi,tachs,tacit,tacks,tacky,tacos,tacso,tacts,taels,taffy,tafia,tagal,tagel,taggy,tagua,tagus,tahar,tahil,tahin,tahrs,tahua,taich,taiga,tails,taily,taino,tains,taint,taipi,taipo,tairn,taise,taish,tajes,tajik,takao,takar,taked,taken,taker,takes,takin,takyr,talak,talao,talar,talas,talck,talcs,taled,taler,tales,talio,talis,talks,talky,talli,tally,talma,talon,talpa,taluk,talus,tamal,tamas,tambo,tamed,tamer,tames,tamil,tamis,tammy,tampa,tamps,tamul,tamus,tanak,tanan,tandy,tanga,tangi,tango,tangs,tangy,tanha,tania,tanka,tanks,tanna,tanny,tanoa,tansy,tanti,tanto,tanya,tanzy,tapas,taped,tapen,taper,tapes,tapet,tapia,tapir,tapis,tapit,tapoa,tappa,tapul,taqua,taraf,tarai,tarau,tarde,tardo,tardy,tarea,tared,tareq,tares,tarfa,targe,tarie,tarin,tarmi,tarns,taroc,tarok,taros,tarot,tarps,tarre,tarri,tarry,tarse,tarsi,tarte,tarts,tarve,tasco,tasks,tasse,taste,tasty,tatar,tater,tates,tatie,tatoo,tatou,tatta,tatty,taube,taula,tauli,taunt,taupe,taupo,tauri,tauts,taver,tavoy,tawed,tawer,tawgi,tawie,tawny,tawpi,tawpy,tawse,taxed,taxer,taxes,taxin,taxir,taxis,taxon,taxor,taxus,tayer,tayir,tayra,tazia,tazza,tazze,tcawi,tchai,tchwi,teach,teaer,teaey,teaks,teals,teams,tears,teart,teary,tease,teasy,teats,teaty,teave,teaze,tebet,techy,tecla,tecon,tecta,tecum,teddy,tedge,teems,teens,teeny,teest,teeth,teety,teffs,tegua,tehee,teian,teiid,teind,teise,tejon,tekke,tekya,telae,telar,teleg,telei,teles,telex,telia,telic,tells,tellt,telly,teloi,telos,telyn,teman,tembe,tembu,temin,temne,tempe,tempi,tempo,temps,tempt,temse,tenai,tench,tendo,tends,tenet,tenez,tengu,tenia,tenio,tenla,tenne,tenno,tennu,tenon,tenor,tense,tenso,tenth,tents,tenty,tenue,tepal,tepas,tepee,tepid,tepor,terai,terap,teras,terce,terek,teres,tereu,terga,terma,terms,terna,terne,terns,terra,terre,terri,terry,terse,terzo,tesla,testa,teste,tests,testy,tetch,tetel,teths,teton,tetra,tetty,tetum,teuch,teugh,tewed,tewel,tewer,tewit,tewly,texan,texas,texts,thack,thais,thala,thana,thane,thank,tharf,tharm,thatd,thatn,thats,thave,thawn,thaws,thawy,theah,theat,theca,theek,theer,theet,theft,thegn,thein,their,thema,theme,thens,theol,theor,theos,theow,there,therm,these,theta,thete,thews,thewy,theyd,thick,thief,thigh,thilk,thill,thine,thing,think,thins,thiol,third,thirl,thirt,thisn,thoft,thoke,thole,tholi,thone,thong,thoom,thore,thorn,thoro,thorp,thort,those,thous,thowt,thram,thrap,thraw,thrax,three,threw,thrip,throb,throe,throu,throw,
thrum,thruv,thuan,thuds,thugs,thuja,thule,thulr,thumb,thump,thund,thung,thuoc,thurl,thurm,thurt,thuya,thyme,thymi,thyms,thymy,tiang,tiara,tibbu,tibby,tiber,tibet,tibey,tibia,tical,ticca,ticer,ticks,ticky,ticul,tidal,tiddy,tided,tides,tiens,tiers,tiffs,tiffy,tiger,tight,tigon,tigre,tigua,tikes,tikis,tikka,tikor,tikur,tilak,tilda,tilde,tiled,tiler,tiles,tilia,tills,tilly,tilth,tilts,tilty,timar,timbe,timbo,timed,timer,times,timet,timid,timne,timon,timor,tinct,tinea,tined,tines,tinge,tingi,tings,tinne,tinni,tinny,tinsy,tinta,tints,tinty,tipis,tipit,tiple,tippy,tipsy,tipup,tiraz,tired,tirer,tires,tirls,tirma,tiros,tirve,tisar,tisic,tissu,titan,titar,titer,tithe,titis,title,titre,titty,titus,tiver,tiwaz,tizzy,tlaco,tmema,toads,toady,toast,today,toddy,todea,todus,toffs,toffy,tofts,tofus,togae,togas,toged,togue,toher,toile,toils,toise,toist,toits,toity,tokay,toked,token,tokes,tokyo,tolan,tolas,toldo,toled,toles,tolls,tolly,tolus,tolyl,toman,tomas,tombe,tombs,tomes,tomia,tomin,tommy,tonal,tondi,tondo,toned,toner,tones,tonga,tongs,tonic,tonka,tonna,tonne,tonto,tonus,tools,toona,toons,toosh,tooth,toots,topas,topau,topaz,toped,topee,toper,topes,tophe,tophi,tophs,topia,topic,topis,topog,topoi,topos,toppy,topsl,topsy,toque,torah,toral,toran,toras,torch,torcs,tored,tores,toret,toric,torii,torma,toros,torse,torsi,torsk,torso,torta,torte,torts,torus,torve,tosca,toshy,tossy,total,toted,totem,toter,totes,totty,totum,touch,tough,tould,tourn,tours,tourt,touse,toust,tousy,touts,tovah,tovar,tovet,towai,towan,towed,towel,tower,towie,towns,towny,towsy,toxic,toxin,toxon,toyed,toyer,toyon,toyos,tozee,tozer,trabu,trace,track,tract,tracy,trade,trady,tragi,traik,trail,train,trait,trama,trame,tramp,trams,trank,trans,trant,trapa,traps,trapt,trash,trass,trasy,trave,trawl,trays,tread,treas,treat,treed,treen,trees,treey,trefa,treks,trema,trend,trent,tress,trest,trets,trews,treys,triac,triad,trial,trias,tribe,trica,trice,trick,tried,trier,tries,trifa,triga,trigo,trigs,trike,trill,trims,trina,trine,trink,triol,trior,trios,tripe,tripl,trips,tript,tripy,trist,trite,trixy,troad,troak,troat,troca,troch,trock,troco,trode,troft,trogs,troic,trois,troke,troll,tromp,trona,tronc,trone,tronk,troop,troot,trooz,trope,troth,trots,troue,trout,trouv,trove,trows,troys,trubu,truce,truck,trudy,trued,truer,trues,truff,trull,truly,trump,trunk,trush,truss,trust,truth,tryma,tryms,trypa,tryst,tsade,tsadi,tsars,tsere,tsine,tsked,tsuba,tsubo,tsuga,tsuma,tuant,tuarn,tuart,tuath,tubae,tubal,tubar,tubas,tubba,tubby,tubed,tuber,tubes,tubig,tubik,
tucks,tucky,tucum,tudel,tudor,tufan,tufas,tuffs,tufts,tufty,tugui,tuism,tukra,tules,tulip,tulle,tulsa,tulsi,tumid,tumli,tummy,tumor,tumps,tunal,tunas,tunca,tuned,tuner,tunes,tunga,tungo,tungs,tunic,tunis,tunka,tunna,tunny,tupek,tupik,tuple,tuque,turbo,turco,turds,turfs,turfy,turgy,turio,turki,turks,turma,turns,turps,turse,turus,turvy,tushs,tushy,tusks,tusky,tutee,tutin,tutly,tutor,tutti,tutto,tutty,tutus,tuxes,tuyer,tuzla,twaes,twain,twait,twale,twalt,twana,twang,twank,twant,twats,tweag,tweak,tweed,tweeg,tweel,tween,tweet,tweil,twere,twerp,twice,twick,twier,twigs,twill,twilt,twine,twink,twins,twint,twiny,twire,twirk,twirl,twirp,twist,twite,twits,twixt,twoes,twyer,tyche,tydie,tyees,tyigh,tying,tyken,tykes,tyler,tylus,tyned,tynes,typal,typed,typer,types,typey,typha,typic,typos,typps,tyred,tyres,tyros,tyste,tythe,tzaam,tzars,
ualis,uaupe,uayeb,uchee,uckia,udasi,udder,udell,udish,ugali,uglis,ugric,uhlan,uhllo,uhuru,uigur,uinal,uinta,ukase,ulama,ulans,ulcer,ulcus,ulema,uller,ulmic,ulmin,ulmus,ulnad,ulnae,ulnar,ulnas,uloid,ulpan,ultra,uluhi,ululu,ulvan,ulvas,umaua,umbel,umber,umble,umbos,umbra,umbre,umest,umiac,umiak,umiaq,umiri,umist,ummps,umped,umpty,umset,unact,unadd,unais,unami,unamo,unapt,unark,unarm,unary,unaus,unbag,unbar,unbay,unbed,unbet,unbid,unbit,unbog,unbow,unbox,unboy,unbud,uncap,uncia,uncle,uncos,uncow,uncoy,uncus,uncut,undam,undee,unden,under,undid,undig,undim,undog,undon,undry,undub,undue,undug,undye,uneye,unfar,unfed,unfew,unfit,unfix,unfur,ungag,unget,ungka,ungod,ungot,ungum,unhad,unhap,unhat,unhex,unhid,unhip,unhit,unhot,uniat,unice,unify,uninn,union,unism,unist,unite,units,unity,unius,unjam,unked,unken,unket,unkey,unkid,unkin,unlap,unlaw,unlax,unlay,unled,unlet,unlid,unlie,unlit,unmad,unman,unmet,unmew,unmix,unnet,unnew,unode,unoil,unold,unona,unorn,unown,unpay,unpeg,unpen,unpin,unpot,unput,unram,unray,unred,unrid,unrig,unrip,unrow,unrra,unrun,unsad,unsay,unsee,unset,unsew,unsex,unshy,unsin,unsly,unson,unsty,unsun,untap,untar,untax,untie,until,untin,untop,unurn,unuse,unwan,unwax,unweb,unwed,unwet,unwig,unwit,unwon,unwry,unzen,unzip,uparm,upaya,upbar,upbay,upbid,upbuy,upbye,upcry,upcut,updos,updry,upeat,upend,upfly,upget,upher,upjet,uplay,upleg,uplit,upmix,upped,upper,uppop,uprid,uprip,uprun,upset,upsey,upsit,upsun,upsup,uptie,upupa,upwax,upway,uraei,urali,urare,urari,urase,urate,urban,urbic,urdee,ureal,ureas,uredo,ureic,ureid,urena,urent,urged,urger,urges,uriah,urial,urian,uriel,urine,urite,urlar,urled,urman,urnae,urnal,ursae,ursal,ursid,urson,ursuk,ursus,urubu,urucu,urutu,usage,usant,usara,usent,users,ushak,ushas,usher,usine,using,uskok,usnea,usnic,usnin,usque,uster,usual,usure,usurp,usury,utchy,utees,utend,uteri,utero,uther,utick,utile,utrum,utsuk,utter,uvala,uvate,uveal,uveas,uviol,uvito,uvres,uvrou,uvula,uvver,uzara,uzbak,uzbeg,uzbek,
vache,vacoa,vacua,vacuo,vadim,vadis,vagal,vagas,vague,vagus,vails,vaire,vairs,vairy,vajra,vakia,vakil,vales,valet,valew,valid,valmy,valor,valsa,valse,value,valva,valve,valyl,vamos,vamps,vance,vanda,vaned,vanes,vangs,vanir,vapid,vapor,vappa,varan,varas,varda,vardy,varec,varia,vario,varix,varna,varus,varve,vasal,vases,vasts,vasty,vates,vatic,vaudy,vault,vaunt,veals,vealy,vedda,vedet,vedic,vedro,veena,veeps,veers,veery,vefry,vegan,vegas,vehme,veils,veily,veins,veiny,vejoz,velal,velar,velds,veldt,velic,velte,velum,venae,venal,vends,vened,venge,venie,venin,venom,venta,vents,venue,venus,vepse,veray,verbs,verby,verde,verdi,verek,verey,verge,vergi,verpa,verre,verry,versa,verse,verso,verst,verts,vertu,verty,verus,verve,vespa,vesta,vests,vetch,veter,vetus,veuve,vexed,vexer,vexes,vexil,viage,vials,viand,vibes,vibex,vibix,vicar,viced,vices,vichy,vicia,vicki,vicky,vicua,vicus,video,vidry,vidua,vidya,viers,views,viewy,vifda,vigas,vigia,vigil,vigor,vijao,vijay,viler,villa,ville,villi,vills,vimen,vimpa,vinal,vinas,vinca,vince,vinci,vinea,vined,viner,vines,vinet,vinew,vingt,vinic,vinny,vinod,vinos,vinta,vinum,vinyl,viola,viols,viper,viral,vireo,vires,virga,virge,virgo,virid,virls,viron,virtu,virus,visas,vised,vises,visie,visit,visne,vison,visor,vista,visto,vitae,vital,vitis,vitra,vitro,vitry,vitta,viuva,vivas,vivat,vivax,vivda,vivek,viver,vives,vivid,vivos,vivre,vixen,vizir,vizor,vizzy,vlach,vobis,vocab,vocal,vocat,voces,voder,vodka,vodum,vodun,vogie,vogue,vogul,voice,voids,voila,voile,volar,voled,voles,volet,volga,volow,volta,volte,volti,volto,volts,volva,vomer,vomit,voraz,votal,voted,voter,votes,vouch,vouge,vouli,voust,vowed,vowel,vower,vraic,vroom,vrouw,vrows,vucom,vuggs,vuggy,vughs,vulgo,vulva,vyase,vying,
waapa,waasi,wabby,wacke,wacks,wacky,waddy,waded,wader,wades,wadge,wadis,wadna,waefu,wafer,waffs,wafts,wafty,waged,wager,wages,waget,wagga,waggy,wagon,wahoo,waifs,wails,waily,wains,waird,wairs,waise,waist,waits,waive,wakan,wakas,waked,waken,waker,wakes,wakhi,wakif,wakon,waled,waler,wales,walks,walla,walls,wally,walsh,walth,walty,waltz,wamel,wames,wamus,wands,wandy,waned,wanes,waney,wanga,wanky,wanle,wanly,wanna,wanny,wants,wanty,wanze,wappo,warch,wards,wared,wares,warks,warly,warms,warns,warnt,warps,warri,warse,warst,warth,warts,warty,warua,warve,wasat,wasco,wasel,washo,washy,wasir,wasnt,wasps,waspy,waste,wasts,wasty,watap,watch,water,watts,wauch,waugh,wauks,wauls,wauns,waura,wauve,waved,waver,waves,wavey,wawah,wawls,waxed,waxen,waxer,waxes,wayao,wayne,wazir,weaky,weald,weals,weans,wears,weary,weave,webby,weber,wecht,wedel,wedge,wedgy,weeda,weeds,weedy,weeks,weens,weent,weeny,weeps,weepy,weesh,weest,weets,weety,weeze,wefts,wefty,wehee,weigh,weird,weirs,weism,wekas,wekau,welch,welds,wells,welly,welsh,welts,wemmy,wench,wende,wendi,wends,wendy,wenny,weren,wersh,weste,wests,westy,wetly,wevet,wezen,whack,whale,whalm,whalp,whaly,whame,whamp,whams,whand,whang,whank,whaps,whare,wharf,wharl,wharp,whart,whase,whata,whatd,whats,whauk,whaup,whaur,wheal,wheam,wheat,wheel,wheem,wheen,wheep,wheer,wheft,whein,wheki,whelk,whelm,whelp,whens,where,whets,whewl,whews,whewt,wheys,whiba,which,whick,whids,whiff,whift,whigs,while,whilk,whill,whils,whims,whine,whing,whins,whiny,whips,whipt,whirl,whirr,whirs,whish,whisk,whisp,whiss,whist,white,whits,whity,whizz,whole,wholl,whomp,whone,whoof,whoop,whoot,whops,whore,whorl,whort,whory,whose,whoso,whsle,whuff,whulk,whump,whush,whute,wicca,wicht,wicks,wicky,widdy,widen,wider,wides,widow,width,wield,wierd,wifed,wifes,wifie,wigan,wiggy,wight,wilco,wilds,wiled,wiles,wilga,willi,wills,willy,wilts,wince,winch,winds,windy,windz,wined,winer,wines,winey,wings,wingy,winks,winly,winna,winos,winze,wiped,wiper,wipes,wired,wirer,wires,wiros,wirra,wised,wisen,wiser,wises,wisha,wisht,wishy,wisps,wispy,wisse,wiste,wists,witan,witch,wited,witen,wites,withe,withy,witty,wived,wiver,wives,wiyat,wiyot,wizen,wizes,wlity,wloka,woads,woady,woald,wocas,woden,wodge,wodgy,woful,wogul,woibe,wokas,woken,wolds,woldy,wolfs,wolly,wolof,wolve,woman,wombs,womby,women,wonga,wonky,wonna,wonts,woods,woody,wooed,wooer,woofs,woofy,woold,woolf,wools,wooly,woomp,woons,woops,woosh,wootz,woozy,wopsy,words,wordy,works,worky,world,worms,wormy,worry,worse,worst,worth,worts,wouch,wough,would,wound,woven,wowed,
wrack,wramp,wrang,wraps,wrapt,wrast,wrath,wrawl,wreak,wreat,wreck,wrens,wrest,wrick,wride,wried,wrier,wries,wring,wrist,write,writh,writs,wrive,wroke,wrong,wroot,wrote,wroth,wrung,wryer,wryly,wudge,wunna,wurly,wurst,wuzzy,wyled,wyles,wynds,wynne,wynns,wyson,wysty,wyted,wytes,wyver,
xebec,xenia,xenic,xenon,xenos,xenyl,xeres,xeric,xerox,xerus,xicak,xinca,xoana,xurel,xviii,xxiii,xylan,xylem,xylia,xylic,xylol,xylon,xylyl,xyrid,xyris,xysti,xysts,
yabbi,yabby,yaboo,yacal,yacca,yacht,yacks,yadim,yaffs,yager,yagis,yagua,yahan,yahoo,yaird,yajna,yakan,yakin,yakka,yakut,yalla,yamel,yamen,yameo,yampa,yamph,yamun,yanan,yangs,yanks,yanky,yaply,yapok,yapon,yappy,yaqui,yarak,yaray,yards,yarer,yarke,yarly,yarns,yarry,yarth,yasht,yasna,yauds,yauld,yaups,yawed,yawey,yawls,yawns,yawny,yawps,yazoo,yclad,yeans,yeara,yeard,yearn,years,yeast,yecch,yechs,yechy,yeech,yeggs,yelek,yelks,yells,yelps,yemen,yenta,yente,yeply,yerba,yerga,yerks,yerth,yerva,yeses,yesso,yesty,yetis,yetts,yeuks,yeuky,yeven,yezdi,yezzy,yfere,ygapo,yield,yikes,yills,yince,yinst,yipes,yirds,yirrs,yirth,ylems,yobbo,yocco,yocks,yodel,yodhs,yodle,yogas,yogee,yoghs,yogic,yogin,yogis,yoick,yojan,yoked,yokel,yoker,yokes,yolks,yolky,yomer,yomim,yomin,yomud,yonic,yonis,yores,youff,young,youre,yourn,yours,yourt,youse,youth,youve,youze,yoven,yowed,yowes,yowie,yowls,yquem,ytter,yuans,yucca,yucch,yuchi,yucks,yucky,yugas,yukon,yulan,yules,yuman,yummy,yunca,yupon,yurak,yurok,yurta,yurts,yuruk,
zabra,zabti,zaire,zakah,zakat,zaman,zambo,zamia,zande,zante,zanza,zanze,zapas,zapus,zaque,zarfs,zaxes,zayat,zayin,zazen,zeals,zebec,zebra,zebub,zebus,zeins,zeism,zeiss,zeist,zemmi,zemni,zendo,zerda,zerma,zeros,zests,zesty,zetas,zhmud,ziara,zibet,ziega,ziffs,zigan,zihar,zilch,zilla,zills,zimbi,zimme,zimmi,zimmy,zinco,zincs,zincy,zineb,zings,zingy,zinke,zinky,zippy,zirai,zirak,ziram,zitis,zizel,zizia,zizit,zlote,zloty,zmudz,zoaea,zocco,zoeae,zoeal,zoeas,zogan,zohak,zoism,zoist,zokor,zolle,zombi,zonal,zonar,zonda,zoned,zoner,zones,zonic,zonta,zooid,zooks,zooms,zoona,zoons,zooty,zoque,zoril,zoris,zorro,zosma,zowie,zucco,zudda,zulus,zunis,zygal,zygon,zymes,zymic,zymin
"""


class Wordle:
    """
    Wordle class

    Use: ``Wordle.solve()``
    """

    def __init__(self, *, green: str = "G", yellow: str = "Y", gray: str = "?") -> None:
        # Setting
        self._ALLOWABLE_CHARACTERS = set(string.ascii_letters)
        self._ALLOWED_ATTEMPTS = 6
        self._WORD_LENGTH = 5

        self._WORDS: list[str] = list(set(OFFLINE_WORDS.replace("\n", "").split(",")))

        self._LETTER_COUNTER = Counter(chain.from_iterable(self._WORDS))

        self._LETTER_FREQUENCY = {
            character: value / sum(self._LETTER_COUNTER.values())
            for character, value in self._LETTER_COUNTER.items()
        }

        # Notation
        self._GREEN = green
        self._YELLOW = yellow
        self._GRAY = gray

    def __str__(self) -> str:
        return self.__repr__()

    def __repr__(self) -> str:
        return self.__class__.__name__

    def update_words(self) -> None:
        """
        Try to fetch words list from online source
        """
        try:
            dict_link = "https://raw.githubusercontent.com/dwyl/english-words/master/words_dictionary.json"
            res = requests.get(dict_link)
            word_list: list[str] = list(res.json().keys())
            self._WORDS = list(
                {
                    word.lower()
                    for word in word_list
                    if len(word) == self._WORD_LENGTH
                    and set(word) < self._ALLOWABLE_CHARACTERS
                }
            )
        except Exception:
            pass

    # Logic
    def _calculate_word_commonality(self, word: str) -> float:
        score = 0.0
        for char in word:
            score += self._LETTER_FREQUENCY[char]
        return score / (self._WORD_LENGTH - len(set(word)) + 1)

    def _sort_by_word_commonality(self) -> list[tuple[str, float]]:
        sort_by = operator.itemgetter(1)
        return sorted(
            [(word, self._calculate_word_commonality(word)) for word in self._WORDS],
            key=sort_by,
            reverse=True,
        )

    def _display_word_table(self, word_commonalities: list[tuple[str, float]]) -> None:
        for word, freq in word_commonalities:
            print(f"{word:<10} | {freq:<5.2}")

    def _input_word(self) -> str:
        while True:
            word = input("Input the word you entered> ")
            if len(word) == self._WORD_LENGTH and word.lower() in self._WORDS:
                break
        return word.lower()

    def _input_response(self) -> str:
        print("Type the color-coded reply from Wordle:")
        print(f"  {self._GREEN} for Green")
        print(f"  {self._YELLOW} for Yellow")
        print(f"  {self._GRAY} for Gray")
        while True:
            response = input("Response from Wordle> ")
            if len(response) == self._WORD_LENGTH and set(response) <= {
                self._GREEN,
                self._YELLOW,
                self._GRAY,
            }:
                break
            else:
                print(f"Error - invalid answer {response}")
        if response == self._GREEN * 5:  # Win
            return "win"
        return response

    def _match_word_vector(self, word: str, word_vector: list[set[str]]) -> bool:
        assert len(word) == len(word_vector)
        for letter, v_letter in zip(word, word_vector):
            if letter not in v_letter:
                return False
        return True

    def _match(
        self, word_vector: list[set[str]], possible_words: list[str]
    ) -> list[str]:
        return [
            word
            for word in possible_words
            if self._match_word_vector(word, word_vector)
        ]

    # Main
    def solve(self) -> None:
        """Solve Wordle"""
        word_vector = [set(string.ascii_lowercase) for _ in range(self._WORD_LENGTH)]

        for attempt in range(1, self._ALLOWED_ATTEMPTS + 1):
            print(f"Attempt {attempt} with {len(self._WORDS)} possible words")
            self._display_word_table(self._sort_by_word_commonality()[:15])
            word = self._input_word()

            response = self._input_response()
            if response == "win":
                print("You Won!")
                break

            for idx, letter in enumerate(response):
                if letter == self._GREEN:
                    word_vector[idx] = {word[idx]}
                elif letter == self._YELLOW:
                    try:
                        word_vector[idx].remove(word[idx])
                    except KeyError:
                        pass
                elif letter == self._GRAY:
                    for vector in word_vector:
                        try:
                            vector.remove(word[idx])
                        except KeyError:
                            pass
            self._WORDS = self._match(word_vector, self._WORDS)


# Run
# ---------------------------------------------------------------------------
if __name__ == "__main__":
    test = Wordle()
    test.solve()
